# -*- coding: utf-8 -*-
# vi:tabstop=4:expandtab:sw=4
import warnings
from sys import version_info

Cache = {}

MUFI = {
    (0, 86): 'V',  # LATIN CAPITAL LETTER V
    (0, 118): 'v',  # LATIN SMALL LETTER V
    (1, 191): 'V',  # LATIN LETTER WYNN
    (1, 247): 'V',  # LATIN CAPITAL LETTER WYNN
    (22, 161): 'V',  # RUNIC LETTER V
    (29, 32): 'v',  # LATIN LETTER SMALL CAPITAL V
    (30, 126): 'V',  # LATIN CAPITAL LETTER V WITH DOT BELOW
    (30, 127): 'v',  # LATIN SMALL LETTER V WITH DOT BELOW
    (30, 252): 'V',  # LATIN CAPITAL LETTER MIDDLE-WELSH V
    (30, 253): 'v',  # LATIN SMALL LETTER MIDDLE-WELSH V
    (33, 35): 'V',  # VERSICLE
    (44, 125): 'V',  # MODIFIER LETTER CAPITAL V
    (167, 94): 'V',  # LATIN CAPITAL LETTER V WITH DIAGONAL STROKE
    (167, 95): 'v',  # LATIN SMALL LETTER V WITH DIAGONAL STROKE
    (167, 104): 'V',  # LATIN CAPITAL LETTER VEND
    (167, 105): 'v',  # LATIN SMALL LETTER VEND
    (227, 58): 'V',  # LATIN CAPITAL LETTER V WITH ACUTE
    (227, 59): 'V',  # LATIN CAPITAL LETTER V WITH CIRCUMFLEX
    (227, 66): 'V',  # LATIN CAPITAL LETTER V WITH DIAERESIS
    (227, 75): 'V',  # LATIN CAPITAL LETTER V WITH DOUBLE ACUTE
    (227, 76): 'V',  # LATIN CAPITAL LETTER V WITH DOT ABOVE
    (227, 77): 'V',  # LATIN CAPITAL LETTER V WITH MACRON
    (227, 78): 'V',  # LATIN CAPITAL LETTER V WITH VERTICAL LINE ABOVE
    (227, 230): 'V',  # LATIN CAPITAL LETTER INSULAR V (VEND) WITH DOT BELOW
    (227, 231): 'V',  # LATIN CAPITAL LETTER INSULAR V (VEND) WITH DOT ABOVE
    (231, 58): 'v',  # LATIN SMALL LETTER V WITH ACUTE
    (231, 59): 'v',  # LATIN SMALL LETTER V WITH CIRCUMFLEX
    (231, 66): 'v',  # LATIN SMALL LETTER V WITH DIAERESIS
    (231, 67): 'v',  # LATIN SMALL LETTER V WITH RING ABOVE
    (231, 75): 'v',  # LATIN SMALL LETTER V WITH DOUBLE ACUTE
    (231, 76): 'v',  # LATIN SMALL LETTER V WITH DOT ABOVE
    (231, 77): 'v',  # LATIN SMALL LETTER V WITH MACRON
    (231, 78): 'v',  # LATIN SMALL LETTER V WITH BAR
    (231, 79): 'v',  # LATIN SMALL LETTER V WITH VERTICAL LINE ABOVE
    (231, 230): 'v',  # LATIN SMALL LETTER INSULAR V (VEND) WITH DOT BELOW
    (231, 231): 'v',  # LATIN SMALL LETTER INSULAR V (VEND) WITH DOT ABOVE
    (232, 186): 'v',  # LATIN SMALL LETTER V WITH SHORT SLASH
    (232, 187): 'v',  # LATIN SMALL LETTER V WITH SHORT SLASH ABOVE RIGHT
    (232, 188): 'v',  # LATIN SMALL LETTER V WITH TWO SHORT SLASHES ABOVE RIGHT
    (235, 186): 'V',  # LATIN CAPITAL LETTER INSULAR V (VEND) WITH ACUTE
    (235, 187): 'v',  # LATIN SMALL LETTER INSULAR V (VEND) WITH ACUTE
    (238, 248): 'v',  # LATIN ENLARGED LETTER SMALL V
    (247, 178): 'V',  # LATIN CAPITAL LETTER V WITH HIGH OVERLINE (ABOVE CHARACTER)
    (0, 65): 'A',  # LATIN CAPITAL LETTER A
    (0, 97): 'a',  # LATIN SMALL LETTER A
    (0, 170): 'A',  # FEMININE ORDINAL INDICATOR
    (0, 192): 'A',  # LATIN CAPITAL LETTER A WITH GRAVE
    (0, 193): 'A',  # LATIN CAPITAL LETTER A WITH ACUTE
    (0, 194): 'A',  # LATIN CAPITAL LETTER A WITH CIRCUMFLEX
    (0, 195): 'A',  # LATIN CAPITAL LETTER A WITH TILDE
    (0, 196): 'A',  # LATIN CAPITAL LETTER A WITH DIAERESIS
    (0, 197): 'A',  # LATIN CAPITAL LETTER A WITH RING ABOVE
    (0, 198): 'AE',  # LATIN CAPITAL LETTER AE
    (0, 224): 'a',  # LATIN SMALL LETTER A WITH GRAVE
    (0, 225): 'a',  # LATIN SMALL LETTER A WITH ACUTE
    (0, 226): 'a',  # LATIN SMALL LETTER A WITH CIRCUMFLEX
    (0, 227): 'a',  # LATIN SMALL LETTER A WITH TILDE
    (0, 228): 'a',  # LATIN SMALL LETTER A WITH DIAERESIS
    (0, 229): 'a',  # LATIN SMALL LETTER A WITH RING ABOVE
    (0, 230): 'ae',  # LATIN SMALL LETTER AE
    (1, 0): 'A',  # LATIN CAPITAL LETTER A WITH MACRON
    (1, 1): 'a',  # LATIN SMALL LETTER A WITH MACRON
    (1, 2): 'A',  # LATIN CAPITAL LETTER A WITH BREVE
    (1, 3): 'a',  # LATIN SMALL LETTER A WITH BREVE
    (1, 4): 'A',  # LATIN CAPITAL LETTER A WITH OGONEK
    (1, 5): 'a',  # LATIN SMALL LETTER A WITH OGONEK
    (1, 226): 'AE',  # LATIN CAPITAL LETTER AE WITH MACRON
    (1, 227): 'ae',  # LATIN SMALL LETTER AE WITH MACRON
    (1, 252): 'AE',  # LATIN CAPITAL LETTER AE WITH ACUTE
    (1, 253): 'ae',  # LATIN SMALL LETTER AE WITH ACUTE
    (2, 38): 'A',  # LATIN CAPITAL LETTER A WITH DOT ABOVE
    (2, 39): 'a',  # LATIN SMALL LETTER A WITH DOT ABOVE
    (22, 168): 'A',  # RUNIC LETTER ANSUZ A
    (29, 0): 'a',  # LATIN LETTER SMALL CAPITAL A
    (29, 1): 'ae',  # LATIN LETTER SMALL CAPITAL AE
    (30, 160): 'A',  # LATIN CAPITAL LETTER A WITH DOT BELOW
    (30, 161): 'a',  # LATIN SMALL LETTER A WITH DOT BELOW
    (30, 162): 'A',  # LATIN CAPITAL LETTER A WITH HOOK ABOVE
    (30, 163): 'a',  # LATIN SMALL LETTER A WITH HOOK ABOVE
    (30, 174): 'A',  # LATIN CAPITAL LETTER A WITH BREVE AND ACUTE
    (30, 175): 'a',  # LATIN SMALL LETTER A WITH BREVE AND ACUTE
    (167, 50): 'AA',  # LATIN CAPITAL LETTER AA
    (167, 51): 'aa',  # LATIN SMALL LETTER AA
    (167, 52): 'AO',  # LATIN CAPITAL LETTER AO
    (167, 53): 'ao',  # LATIN SMALL LETTER AO
    (167, 54): 'AU',  # LATIN CAPITAL LETTER AU
    (167, 55): 'au',  # LATIN SMALL LETTER AU
    (167, 56): 'AV',  # LATIN CAPITAL LETTER AV
    (167, 57): 'av',  # LATIN SMALL LETTER AV
    (167, 58): 'AV',  # LATIN CAPITAL LETTER AV WITH HORIZONTAL BAR
    (167, 59): 'av',  # LATIN SMALL LETTER AV WITH HORIZONTAL BAR
    (167, 60): 'AY',  # LATIN CAPITAL LETTER AY
    (167, 61): 'ay',  # LATIN SMALL LETTER AY
    (224, 4): 'A',  # LATIN CAPITAL LETTER A WITH OGONEK AND ACUTE
    (224, 10): 'A',  # LATIN CAPITAL LETTER A WITH MACRON AND ACUTE
    (224, 16): 'A',  # LATIN CAPITAL LETTER A WITH MACRON AND BREVE
    (224, 37): 'A',  # LATIN CAPITAL LETTER A WITH DOUBLE ACUTE
    (224, 44): 'ae',  # LATIN CAPITAL LETTER A WITH LATIN SMALL LETTER E ABOVE
    (224, 51): 'A',  # LATIN CAPITAL LETTER A WITH CURL
    (224, 54): 'AE',  # LATIN CAPITAL LETTER AE WITH DOT BELOW
    (224, 58): 'AE',  # LATIN CAPITAL LETTER AE WITH MACRON AND ACUTE
    (224, 61): 'AE',  # LATIN CAPITAL LETTER AE WITH MACRON AND BREVE
    (224, 63): 'AE',  # LATIN CAPITAL LETTER AE WITH BREVE
    (224, 64): 'AE',  # LATIN CAPITAL LETTER AE WITH OGONEK
    (224, 65): 'AE',  # LATIN CAPITAL LETTER AE WITH DOUBLE ACUTE
    (224, 66): 'AE',  # LATIN CAPITAL LETTER AE WITH DIAERESIS
    (224, 67): 'AE',  # LATIN CAPITAL LETTER AE WITH DOT ABOVE
    (228, 4): 'a',  # LATIN SMALL LETTER A WITH OGONEK AND ACUTE
    (228, 10): 'a',  # LATIN SMALL LETTER A WITH MACRON AND ACUTE
    (228, 16): 'a',  # LATIN SMALL LETTER A WITH MACRON AND BREVE
    (228, 26): 'a',  # LATIN SMALL LETTER A WITH DIAERESIS AND CIRCUMFLEX
    (228, 29): 'a',  # LATIN SMALL LETTER A WITH DIAERESIS AND DOT BELOW
    (228, 31): 'a',  # LATIN SMALL LETTER A WITH RING ABOVE AND CIRCUMFLEX
    (228, 37): 'a',  # LATIN SMALL LETTER A WITH DOUBLE ACUTE
    (228, 44): 'ae',  # LATIN SMALL LETTER A WITH LATIN SMALL LETTER E ABOVE
    (228, 45): 'ao',  # LATIN SMALL LETTER A WITH LATIN SMALL LETTER O ABOVE
    (228, 46): 'av',  # LATIN SMALL LETTER A WITH LATIN SMALL LETTER V ABOVE
    (228, 51): 'a',  # LATIN SMALL LETTER A WITH CURL
    (228, 54): 'ae',  # LATIN SMALL LETTER AE WITH DOT BELOW
    (228, 58): 'ae',  # LATIN SMALL LETTER AE WITH MACRON AND ACUTE
    (228, 61): 'ae',  # LATIN SMALL LETTER AE WITH MACRON AND BREVE
    (228, 63): 'ae',  # LATIN SMALL LETTER AE WITH BREVE
    (228, 64): 'ae',  # LATIN SMALL LETTER AE WITH OGONEK
    (228, 65): 'ae',  # LATIN SMALL LETTER AE WITH DOUBLE ACUTE
    (228, 66): 'ae',  # LATIN SMALL LETTER AE WITH DIAERESIS
    (228, 67): 'ae',  # LATIN SMALL LETTER AE WITH DOT ABOVE
    (232, 209): 'ae',  # LATIN SMALL LETTER AE WITH RING ABOVE
    (232, 211): 'ae',  # LATIN SMALL LETTER AE WITH OGONEK AND ACUTE
    (232, 213): 'a',  # LATIN SMALL LETTER A WITH DIAGONAL DIAERESIS
    (232, 224): 'ai',  # LATIN SMALL LETTER A WITH LATIN SMALL LETTER I ABOVE
    (232, 225): 'au',  # LATIN SMALL LETTER A WITH LATIN SMALL LETTER U ABOVE
    (234, 240): 'a',  # LATIN ENLARGED LETTER SMALL A WITH ACUTE
    (234, 241): 'ae',  # LATIN ENLARGED LETTER SMALL LIGATURE AE
    (234, 242): 'ao',  # LATIN LIGATURE ENLARGED LETTER SMALL A AND LATIN SMALL LETTER O
    (235, 176): 'AV',  # LATIN CAPITAL LIGATURE AV WITH STROKE AND ACUTE
    (235, 177): 'av',  # LATIN SMALL LIGATURE AV WITH STROKE AND ACUTE
    (235, 192): 'AO',  # LATIN CAPITAL LIGATURE AO WITH DOUBLE ACUTE
    (235, 193): 'ao',  # LATIN SMALL LIGATURE AO WITH DOUBLE ACUTE
    (235, 194): 'AV',  # LATIN CAPITAL LIGATURE AV WITH DOUBLE ACUTE
    (235, 195): 'av',  # LATIN SMALL LIGATURE AV WITH DOUBLE ACUTE
    (235, 234): 'AE',  # LATIN CAPITAL LETTER AE WITH CURL
    (235, 235): 'ae',  # LATIN SMALL LETTER AE WITH CURL
    (235, 240): 'AV',  # LATIN CAPITAL LIGATURE AV WITH OGONEK
    (235, 241): 'av',  # LATIN SMALL LIGATURE AV WITH OGONEK
    (235, 244): 'A',  # LATIN CAPITAL LETTER A WITH DOT ABOVE AND ACUTE
    (235, 245): 'a',  # LATIN SMALL LETTER A WITH DOT ABOVE AND ACUTE
    (238, 224): 'a',  # LATIN ENLARGED LETTER SMALL A
    (239, 160): 'aa',  # LATIN SMALL LIGATURE AA CLOSED FORM
    (239, 161): 'ae',  # LATIN SMALL LIGATURE NECKLESS A E
    (239, 162): 'av',  # LATIN SMALL LIGATURE NECKLESS A V
    (239, 163): 'af',  # LATIN SMALL LIGATURE AF
    (239, 164): 'af',  # LATIN SMALL LIGATURE A INSULAR F
    (239, 165): 'ag',  # LATIN SMALL LIGATURE AG
    (239, 166): 'al',  # LATIN SMALL LIGATURE AL
    (239, 167): 'an',  # LATIN SMALL LIGATURE AN
    (239, 168): 'an',  # LATIN SMALL LIGATURE A SMALL CAPITAL N
    (239, 169): 'ap',  # LATIN SMALL LIGATURE AP
    (239, 170): 'ar',  # LATIN SMALL LIGATURE AR
    (239, 171): 'ar',  # LATIN SMALL LIGATURE A SMALL CAPITAL R
    (239, 172): 'ath',  # LATIN SMALL LIGATURE A THORN
    (239, 174): 'AE',  # LATIN CAPITAL LIGATURE NECKLESS A E
    (239, 219): 'AE',  # LATIN CAPITAL LETTER AE WITH DOT ABOVE AND ACUTE
    (239, 220): 'ae',  # LATIN SMALL LETTER AE WITH DOT ABOVE AND ACUTE
    (239, 222): 'ao',  # LATIN ENLARGED LETTER SMALL LIGATURE AO
    (239, 223): 'aa',  # LATIN ENLARGED LETTER SMALL LIGATURE AA
    (239, 224): 'AA',  # LATIN CAPITAL LIGATURE AA WITH ACUTE
    (239, 225): 'aa',  # LATIN SMALL LIGATURE AA WITH ACUTE
    (239, 226): 'AO',  # LATIN CAPITAL LIGATURE AO WITH ACUTE
    (239, 227): 'ao',  # LATIN SMALL LIGATURE AO WITH ACUTE
    (239, 228): 'AU',  # LATIN CAPITAL LIGATURE AU WITH ACUTE
    (239, 229): 'au',  # LATIN SMALL LIGATURE AU WITH ACUTE
    (239, 230): 'AV',  # LATIN CAPITAL LIGATURE AV WITH ACUTE
    (239, 231): 'av',  # LATIN SMALL LIGATURE AV WITH ACUTE
    (239, 234): 'AA',  # LATIN CAPITAL LIGATURE AA WITH DOUBLE ACUTE
    (239, 235): 'aa',  # LATIN SMALL LIGATURE AA WITH DOUBLE ACUTE
    (239, 238): 'AA',  # LATIN CAPITAL LIGATURE AA WITH DOT ABOVE
    (239, 239): 'aa',  # LATIN SMALL LIGATURE AA WITH DOT ABOVE
    (239, 240): 'AY',  # LATIN CAPITAL LIGATURE AY WITH DOT ABOVE
    (239, 241): 'ay',  # LATIN SMALL LIGATURE AY WITH DOT ABOVE
    (239, 242): 'AA',  # LATIN CAPITAL LIGATURE AA WITH DOT BELOW
    (239, 243): 'aa',  # LATIN SMALL LIGATURE AA WITH DOT BELOW
    (239, 244): 'AO',  # LATIN CAPITAL LIGATURE AO WITH DOT BELOW
    (239, 245): 'ao',  # LATIN SMALL LIGATURE AO WITH DOT BELOW
    (239, 246): 'AU',  # LATIN CAPITAL LIGATURE AU WITH DOT BELOW
    (239, 247): 'au',  # LATIN SMALL LIGATURE AU WITH DOT BELOW
    (239, 248): 'AV',  # LATIN CAPITAL LIGATURE AV WITH DOT BELOW
    (239, 249): 'av',  # LATIN SMALL LIGATURE AV WITH DOT BELOW
    (239, 250): 'AY',  # LATIN CAPITAL LIGATURE AY WITH DOT BELOW
    (239, 251): 'ay',  # LATIN SMALL LIGATURE AY WITH DOT BELOW
    (239, 254): 'AA',  # LATIN CAPITAL LIGATURE AA WITH DIAERESIS
    (239, 255): 'aa',  # LATIN SMALL LIGATURE AA WITH DIAERESIS
    (241, 58): 'A',  # LATIN CAPITAL LETTER A SQUARE FORM
    (242, 0): 'a',  # LATIN SMALL LETTER A INSULAR FORM
    (242, 1): 'A',  # LATIN CAPITAL LETTER A INSULAR FORM
    (242, 2): 'a',  # LATIN SMALL LETTER OPEN A CAROLINGIAN FORM
    (242, 3): 'a',  # LATIN SMALL LETTER CLOSED A GOTHIC FORM
    (242, 4): 'ae',  # LATIN SMALL LETTER AE WITH RIGHT UPPER LOOP
    (242, 5): 'AO',  # LATIN CAPITAL LIGATURE AO NECKLESS
    (242, 6): 'ao',  # LATIN SMALL LIGATURE AO NECKLESS
    (242, 20): 'a',  # LATIN SMALL LETTER A UNCIAL FORM
    (242, 21): 'a',  # LATIN SMALL LETTER NECKLESS A
    (0, 67): 'C',  # LATIN CAPITAL LETTER C
    (0, 99): 'c',  # LATIN SMALL LETTER C
    (0, 199): 'C',  # LATIN CAPITAL LETTER C WITH CEDILLA
    (0, 231): 'c',  # LATIN SMALL LETTER C WITH CEDILLA
    (1, 6): 'C',  # LATIN CAPITAL LETTER C WITH ACUTE
    (1, 7): 'c',  # LATIN SMALL LETTER C WITH ACUTE
    (1, 10): 'C',  # LATIN CAPITAL LETTER C WITH DOT ABOVE
    (1, 11): 'c',  # LATIN SMALL LETTER C WITH DOT ABOVE
    (29, 4): 'c',  # LATIN LETTER SMALL CAPITAL C
    (33, 132): 'c',  # LATIN ABBREVIATION SIGN SMALL CON
    (224, 102): 'C',  # LATIN CAPITAL LETTER C WITH DOT BELOW
    (224, 118): 'C',  # LATIN CAPITAL LETTER C WITH OGONEK
    (228, 102): 'c',  # LATIN SMALL LETTER C WITH DOT BELOW
    (228, 118): 'c',  # LATIN SMALL LETTER C WITH OGONEK
    (238, 196): 'ck',  # LATIN SMALL LIGATURE CK
    (238, 197): 'ct',  # LATIN SMALL LIGATURE CT
    (238, 226): 'c',  # LATIN ENLARGED LETTER SMALL C
    (241, 6): 'C',  # LATIN CAPITAL LETTER C SQUARE FORM
    (241, 152): 'c',  # LATIN SMALL LETTER C WITH CURL
    (241, 187): 'ch',  # LATIN SMALL LIGATURE CH
    (242, 254): 'C',  # ROMAN NUMERAL CAPITAL C WITH TWO BARS
    (242, 255): 'c',  # ROMAN NUMERAL SMALL C WITH TWO BARS
    (247, 181): 'C',  # LATIN CAPITAL LETTER C WITH HIGH OVERLINE (ABOVE CHARACTER)
    (0, 83): 'S',  # LATIN CAPITAL LETTER S
    (0, 115): 's',  # LATIN SMALL LETTER S
    (0, 223): 's',  # LATIN SMALL LETTER SHARP S
    (1, 90): 'S',  # LATIN CAPITAL LETTER S WITH ACUTE
    (1, 91): 's',  # LATIN SMALL LETTER S WITH ACUTE
    (1, 127): 's',  # LATIN SMALL LETTER LONG S
    (30, 96): 'S',  # LATIN CAPITAL LETTER S WITH DOT ABOVE
    (30, 97): 's',  # LATIN SMALL LETTER S WITH DOT ABOVE
    (30, 98): 'S',  # LATIN CAPITAL LETTER S WITH DOT BELOW
    (30, 99): 's',  # LATIN SMALL LETTER S WITH DOT BELOW
    (30, 156): 's',  # LATIN SMALL LETTER LONG S WITH DIAGONAL STROKE
    (30, 157): 's',  # LATIN SMALL LETTER LONG S WITH HIGH STROKE
    (30, 158): 'S',  # LATIN CAPITAL LETTER SHARP S
    (167, 49): 's',  # LATIN LETTER SMALL CAPITAL S
    (167, 132): 'S',  # LATIN CAPITAL LETTER INSULAR S
    (167, 133): 's',  # LATIN SMALL LETTER INSULAR S
    (231, 158): 's',  # LATIN SMALL LETTER LONG S WITH MEDIUM-HIGH OVERLINE (ACROSS ASCENDER)
    (231, 194): 's',  # LATIN SMALL LETTER LONG S WITH DOT BELOW
    (232, 183): 's',  # LATIN SMALL LETTER LONG S WITH FLOURISH
    (232, 184): 's',  # LATIN SMALL LETTER LONG S WITH SLANTED DESCENDING STROKE
    (232, 223): 'sl',  # LATIN SMALL LIGATURE LONG S L WITH STROKE
    (234, 218): 'st',  # LATIN SMALL LIGATURE LONG S DESCENDING T
    (235, 160): 'sa',  # LATIN SMALL LIGATURE LONG S A WITH DIAERESIS
    (235, 161): 'sh',  # LATIN SMALL LIGATURE LONG S H
    (235, 162): 'si',  # LATIN SMALL LIGATURE LONG S I
    (235, 163): 'sl',  # LATIN SMALL LIGATURE LONG S L
    (235, 164): 'so',  # LATIN SMALL LIGATURE LONG S O WITH DIAERESIS
    (235, 165): 'sp',  # LATIN SMALL LIGATURE LONG S P
    (235, 166): 'ss',  # LATIN SMALL LIGATURE LONG S LONG S
    (235, 167): 'ssi',  # LATIN SMALL LIGATURE LONG S LONG S I
    (235, 168): 'ssl',  # LATIN SMALL LIGATURE LONG S LONG S L
    (235, 169): 'sti',  # LATIN SMALL LIGATURE LONG S TI
    (235, 170): 'str',  # LATIN SMALL LIGATURE LONG S TR
    (235, 171): 'su',  # LATIN SMALL LIGATURE LONG S U WITH DIAERESIS
    (235, 172): 'sv',  # LATIN SMALL LIGATURE LONG S INSULAR V
    (235, 175): 's',  # LATIN SMALL LETTER LONG S WITH ACUTE
    (238, 223): 's',  # LATIN ENLARGED LETTER SMALL LONG S
    (238, 244): 's',  # LATIN ENLARGED LETTER SMALL S
    (239, 35): 'S',  # LATIN LETTER SMALL CAPITAL S WITH DOT ABOVE
    (239, 44): 'S',  # LATIN LETTER SMALL CAPITAL S WITH DOT BELOW
    (241, 38): 'S',  # LATIN CAPITAL LETTER S CLOSED FORM
    (241, 39): 's',  # LATIN SMALL LETTER LONG S DESCENDING
    (241, 40): 's',  # LATIN SMALL LETTER S CLOSED FORM
    (244, 250): 'sch',  # LATIN SMALL LIGATURE LONG S CH
    (244, 251): 'sj',  # LATIN SMALL LIGATURE LONG S J
    (244, 252): 'sk',  # LATIN SMALL LIGATURE LONG S K
    (244, 253): 'ss',  # LATIN SMALL LIGATURE LONG S S
    (244, 254): 'ssk',  # LATIN SMALL LIGATURE LONG S LONG S K
    (244, 255): 'sst',  # LATIN SMALL LIGATURE LONG S LONG S T
    (251, 5): 's',  # LATIN SMALL LIGATURE LONG S T
    (251, 6): 's',  # LATIN SMALL LIGATURE ST
    (0, 90): 'Z',  # LATIN CAPITAL LETTER Z
    (0, 122): 'z',  # LATIN SMALL LETTER Z
    (1, 123): 'Z',  # LATIN CAPITAL LETTER Z WITH DOT ABOVE
    (1, 124): 'z',  # LATIN SMALL LETTER Z WITH DOT ABOVE
    (1, 181): 'Z',  # LATIN CAPITAL LETTER Z WITH STROKE
    (1, 182): 'z',  # LATIN SMALL LETTER Z WITH STROKE
    (29, 34): 'z',  # LATIN LETTER SMALL CAPITAL Z
    (30, 146): 'Z',  # LATIN CAPITAL LETTER Z WITH DOT BELOW
    (30, 147): 'z',  # LATIN SMALL LETTER Z WITH DOT BELOW
    (167, 98): 'Z',  # LATIN CAPITAL LETTER VISIGOTHIC Z
    (167, 99): 'z',  # LATIN SMALL LETTER VISIGOTHIC Z
    (238, 252): 'z',  # LATIN ENLARGED LETTER SMALL Z
    (0, 85): 'U',  # LATIN CAPITAL LETTER U
    (0, 117): 'u',  # LATIN SMALL LETTER U
    (0, 217): 'U',  # LATIN CAPITAL LETTER U WITH GRAVE
    (0, 218): 'U',  # LATIN CAPITAL LETTER U WITH ACUTE
    (0, 219): 'U',  # LATIN CAPITAL LETTER U WITH CIRCUMFLEX
    (0, 220): 'U',  # LATIN CAPITAL LETTER U WITH DIAERESIS
    (0, 249): 'u',  # LATIN SMALL LETTER U WITH GRAVE
    (0, 250): 'u',  # LATIN SMALL LETTER U WITH ACUTE
    (0, 251): 'u',  # LATIN SMALL LETTER U WITH CIRCUMFLEX
    (0, 252): 'u',  # LATIN SMALL LETTER U WITH DIAERESIS
    (1, 106): 'U',  # LATIN CAPITAL LETTER U WITH MACRON
    (1, 107): 'u',  # LATIN SMALL LETTER U WITH MACRON
    (1, 108): 'U',  # LATIN CAPITAL LETTER U WITH BREVE
    (1, 109): 'u',  # LATIN SMALL LETTER U WITH BREVE
    (1, 110): 'U',  # LATIN CAPITAL LETTER U WITH RING ABOVE
    (1, 111): 'u',  # LATIN SMALL LETTER U WITH RING ABOVE
    (1, 112): 'U',  # LATIN CAPITAL LETTER U WITH DOUBLE ACUTE
    (1, 113): 'u',  # LATIN SMALL LETTER U WITH DOUBLE ACUTE
    (1, 114): 'U',  # LATIN CAPITAL LETTER U WITH OGONEK
    (1, 115): 'u',  # LATIN SMALL LETTER U WITH OGONEK
    (1, 211): 'U',  # LATIN CAPITAL LETTER U WITH CARON
    (1, 212): 'u',  # LATIN SMALL LETTER U WITH CARON
    (1, 213): 'U',  # LATIN CAPITAL LETTER U WITH DIAERESIS AND MACRON
    (1, 214): 'u',  # LATIN SMALL LETTER U WITH DIAERESIS AND MACRON
    (2, 137): 'u',  # LATIN SMALL LETTER U BAR
    (22, 162): 'U',  # RUNIC LETTER URUZ UR U
    (29, 28): 'u',  # LATIN LETTER SMALL CAPITAL U
    (29, 107): 'u',  # LATIN SMALL LETTER UE
    (30, 228): 'U',  # LATIN CAPITAL LETTER U WITH DOT BELOW
    (30, 229): 'u',  # LATIN SMALL LETTER U WITH DOT BELOW
    (30, 230): 'U',  # LATIN CAPITAL LETTER U WITH HOOK ABOVE
    (30, 231): 'u',  # LATIN SMALL LETTER U WITH HOOK ABOVE
    (227, 9): 'U',  # LATIN CAPITAL LETTER U WITH MACRON AND ACUTE
    (227, 11): 'U',  # LATIN CAPITAL LETTER U WITH MACRON AND BREVE
    (227, 21): 'U',  # LATIN CAPITAL LETTER U WITH DOT ABOVE
    (227, 23): 'U',  # LATIN CAPITAL LETTER U WITH DIAERESIS AND CIRCUMFLEX
    (227, 36): 'U',  # LATIN CAPITAL LETTER U WITH VERTICAL LINE ABOVE
    (227, 43): 'UE',  # LATIN CAPITAL LETTER U WITH LATIN SMALL LETTER E ABOVE
    (227, 45): 'UO',  # LATIN CAPITAL LETTER U WITH LATIN SMALL LETTER O ABOVE
    (227, 49): 'U',  # LATIN CAPITAL LETTER U WITH CURL
    (231, 9): 'u',  # LATIN SMALL LETTER U WITH MACRON AND ACUTE
    (231, 11): 'u',  # LATIN SMALL LETTER U WITH MACRON AND BREVE
    (231, 21): 'u',  # LATIN SMALL LETTER U WITH DOT ABOVE
    (231, 23): 'u',  # LATIN SMALL LETTER U WITH DIAERESIS AND CIRCUMFLEX
    (231, 36): 'u',  # LATIN SMALL LETTER U WITH VERTICAL LINE ABOVE
    (231, 39): 'u',  # LATIN SMALL LETTER U WITH INVERTED BREVE BELOW
    (231, 43): 'ue',  # LATIN SMALL LETTER U WITH LATIN SMALL LETTER E ABOVE
    (231, 44): 'ui',  # LATIN SMALL LETTER U WITH LATIN SMALL LETTER I ABOVE
    (231, 45): 'uo',  # LATIN SMALL LETTER U WITH LATIN SMALL LETTER O ABOVE
    (231, 49): 'u',  # LATIN SMALL LETTER U WITH CURL
    (232, 198): 'UU',  # LATIN CAPITAL LIGATURE UU
    (232, 199): 'uu',  # LATIN SMALL LIGATURE UU
    (232, 200): 'UE',  # LATIN CAPITAL LIGATURE UE
    (232, 201): 'ue',  # LATIN SMALL LIGATURE UE
    (232, 235): 'ua',  # LATIN SMALL LETTER U WITH LATIN SMALL LETTER A ABOVE
    (232, 236): 'uv',  # LATIN SMALL LETTER U WITH LATIN SMALL LETTER V ABOVE
    (232, 237): 'uw',  # LATIN SMALL LETTER U WITH LATIN SMALL LETTER W ABOVE
    (235, 191): 'u',  # LATIN SMALL LETTER U WITH CURLY BAR ABOVE
    (235, 254): 'U',  # LATIN CAPITAL LETTER U WITH DOT ABOVE AND ACUTE
    (235, 255): 'u',  # LATIN SMALL LETTER U WITH DOT ABOVE AND ACUTE
    (238, 247): 'u',  # LATIN ENLARGED LETTER SMALL U
    (239, 216): 'uu',  # LATIN SMALL LIGATURE UU WITH DOUBLE ACUTE
    (239, 217): 'UU',  # LATIN CAPITAL LIGATURE UU WITH DOUBLE ACUTE
    (0, 68): 'D',  # LATIN CAPITAL LETTER D
    (0, 100): 'd',  # LATIN SMALL LETTER D
    (0, 208): 'eth',  # LATIN CAPITAL LETTER ETH
    (0, 240): 'eth',  # LATIN SMALL LETTER ETH
    (1, 16): 'D',  # LATIN CAPITAL LETTER D WITH STROKE
    (1, 17): 'd',  # LATIN SMALL LETTER D WITH STROKE
    (2, 86): 'd',  # LATIN SMALL LETTER D WITH TAIL
    (22, 167): 'eth',  # RUNIC LETTER ETH
    (29, 5): 'd',  # LATIN LETTER SMALL CAPITAL D
    (29, 6): 'd',  # LATIN LETTER SMALL CAPITAL ETH
    (30, 10): 'D',  # LATIN CAPITAL LETTER D WITH DOT ABOVE
    (30, 11): 'd',  # LATIN SMALL LETTER D WITH DOT ABOVE
    (30, 12): 'D',  # LATIN CAPITAL LETTER D WITH DOT BELOW
    (30, 13): 'd',  # LATIN SMALL LETTER D WITH DOT BELOW
    (30, 159): 'd',  # LATIN SMALL LETTER DELTA
    (167, 113): 'd',  # LATIN SMALL LETTER DUM
    (167, 121): 'D',  # LATIN CAPITAL LETTER INSULAR D
    (167, 122): 'd',  # LATIN SMALL LETTER INSULAR D
    (224, 119): 'D',  # LATIN CAPITAL LETTER D WITH ACUTE
    (224, 143): 'ETH',  # LATIN CAPITAL LETTER ETH WITH DOT BELOW
    (228, 119): 'd',  # LATIN SMALL LETTER D WITH ACUTE
    (228, 143): 'eth',  # LATIN SMALL LETTER ETH WITH DOT BELOW
    (228, 145): 'd',  # LATIN SMALL LETTER D WITH MEDIUM-HIGH OVERLINE (ACROSS ASCENDER)
    (235, 178): 'd',  # LATIN SMALL LETTER D ROTUNDA WITH ACUTE
    (235, 209): 'd',  # LATIN SMALL LETTER D ROTUNDA WITH DOT ABOVE
    (235, 210): 'D',  # LATIN LETTER SMALL CAPITAL D WITH DOT ABOVE
    (238, 198): 'dd',  # LATIN SMALL LIGATURE DD ROTUNDA
    (238, 227): 'd',  # LATIN ENLARGED LETTER SMALL D
    (238, 228): 'd',  # LATIN ENLARGED LETTER D ROTUNDA
    (238, 229): 'eth',  # LATIN ENLARGED LETTER SMALL ETH
    (239, 38): 'D',  # LATIN LETTER SMALL CAPITAL D WITH DOT BELOW
    (241, 147): 'd',  # LATIN SMALL LETTER D WITH CURL
    (247, 182): 'D',  # LATIN CAPITAL LETTER D WITH HIGH OVERLINE (ABOVE CHARACTER)
    (0, 66): 'B',  # LATIN CAPITAL LETTER B
    (0, 98): 'b',  # LATIN SMALL LETTER B
    (1, 128): 'b',  # LATIN SMALL LETTER B WITH STROKE
    (2, 153): 'b',  # LATIN LETTER SMALL CAPITAL B
    (30, 2): 'B',  # LATIN CAPITAL LETTER B WITH DOT ABOVE
    (30, 3): 'b',  # LATIN SMALL LETTER B WITH DOT ABOVE
    (30, 4): 'B',  # LATIN CAPITAL LETTER B WITH DOT BELOW
    (30, 5): 'b',  # LATIN SMALL LETTER B WITH DOT BELOW
    (224, 68): 'B',  # LATIN CAPITAL LETTER B WITH ACUTE
    (228, 68): 'b',  # LATIN SMALL LETTER B WITH ACUTE
    (228, 77): 'b',  # LATIN SMALL LETTER B WITH MEDIUM-HIGH OVERLINE (ACROSS ASCENDER)
    (235, 208): 'B',  # LATIN LETTER SMALL CAPITAL B WITH DOT ABOVE
    (238, 194): 'bb',  # LATIN SMALL LIGATURE BB
    (238, 195): 'bg',  # LATIN SMALL LIGATURE BG
    (238, 225): 'b',  # LATIN ENLARGED LETTER SMALL B
    (239, 37): 'B',  # LATIN LETTER SMALL CAPITAL B WITH DOT BELOW
    (3, 0): '',  # COMBINING GRAVE ACCENT
    (3, 1): '',  # COMBINING ACUTE ACCENT
    (3, 2): '',  # COMBINING CIRCUMFLEX ACCENT
    (3, 3): '',  # COMBINING TILDE
    (3, 4): '',  # COMBINING MACRON
    (3, 5): '',  # COMBINING OVERLINE
    (3, 6): '',  # COMBINING BREVE
    (3, 7): '',  # COMBINING DOT ABOVE
    (3, 8): '',  # COMBINING DIAERESIS
    (3, 9): '',  # COMBINING HOOK ABOVE
    (3, 10): '',  # COMBINING RING ABOVE
    (3, 11): '',  # COMBINING DOUBLE ACUTE ACCENT
    (3, 13): '',  # COMBINING VERTICAL LINE ABOVE
    (3, 14): '',  # COMBINING DOUBLE VERTICAL LINE ABOVE
    (3, 21): '',  # COMBINING COMMA ABOVE RIGHT
    (3, 35): '',  # COMBINING DOT BELOW
    (3, 39): '',  # COMBINING CEDILLA
    (3, 40): '',  # COMBINING OGONEK
    (3, 50): '',  # COMBINING LOW LINE
    (3, 51): '',  # COMBINING DOUBLE LOW LINE
    (3, 54): '',  # COMBINING LONG STROKE OVERLAY
    (3, 62): '',  # COMBINING VERTICAL TILDE
    (3, 63): '',  # COMBINING DOUBLE OVERLINE
    (3, 89): '',  # COMBINING ASTERISK BELOW
    (3, 91): '',  # COMBINING ZIGZAG ABOVE
    (3, 92): '',  # COMBINING DOUBLE BREVE BELOW
    (3, 96): '',  # COMBINING DOUBLE TILDE
    (3, 99): 'a',  # COMBINING LATIN SMALL LETTER A
    (3, 100): 'e',  # COMBINING LATIN SMALL LETTER E
    (3, 101): 'i',  # COMBINING LATIN SMALL LETTER I
    (3, 102): 'o',  # COMBINING LATIN SMALL LETTER O
    (3, 103): 'u',  # COMBINING LATIN SMALL LETTER U
    (3, 104): 'c',  # COMBINING LATIN SMALL LETTER C
    (3, 105): 'd',  # COMBINING LATIN SMALL LETTER D
    (3, 106): 'h',  # COMBINING LATIN SMALL LETTER H
    (3, 107): 'm',  # COMBINING LATIN SMALL LETTER M
    (3, 108): 'r',  # COMBINING LATIN SMALL LETTER R
    (3, 109): 't',  # COMBINING LATIN SMALL LETTER T
    (3, 110): 'v',  # COMBINING LATIN SMALL LETTER V
    (3, 111): 'x',  # COMBINING LATIN SMALL LETTER X
    (29, 205): '',  # COMBINING DOUBLE CIRCUMFLEX ABOVE
    (29, 206): '',  # COMBINING OGONEK ABOVE
    (29, 207): '',  # COMBINING ZIGZAG BELOW
    (29, 208): 'is',  # COMBINING IS BELOW
    (29, 209): 'ur',  # COMBINING UR ABOVE
    (29, 210): 'us',  # COMBINING US ABOVE
    (29, 211): '',  # COMBINING LATIN SMALL LETTER FLATTENED OPEN A ABOVE
    (29, 212): 'a',  # COMBINING LATIN SMALL LETTER AE
    (29, 213): 'ae',  # COMBINING LATIN SMALL LIGATURE AO
    (29, 214): 'ao',  # COMBINING LATIN SMALL LIGATURE AV
    (29, 215): 'av',  # COMBINING LATIN SMALL LETTER C CEDILLA
    (29, 216): 'c',  # COMBINING LATIN LETTER INSULAR D
    (29, 217): 'd',  # COMBINING LATIN SMALL LETTER ETH
    (29, 218): 'g',  # COMBINING LATIN SMALL LETTER G
    (29, 219): 'g',  # COMBINING LATIN LETTER SMALL CAPITAL G
    (29, 220): 'k',  # COMBINING LATIN SMALL LETTER K
    (29, 221): 'l',  # COMBINING LATIN SMALL LETTER L
    (29, 222): 'l',  # COMBINING LATIN LETTER SMALL CAPITAL L
    (29, 223): 'm',  # COMBINING LATIN LETTER SMALL CAPITAL M
    (29, 224): 'n',  # COMBINING LATIN SMALL LETTER N
    (29, 225): 'n',  # COMBINING LATIN LETTER SMALL CAPITAL N
    (29, 226): 'r',  # COMBINING LATIN LETTER SMALL CAPITAL R
    (29, 227): 'r',  # COMBINING LATIN SMALL LETTER R ROTUNDA
    (29, 228): 's',  # COMBINING LATIN SMALL LETTER S
    (29, 229): 's',  # COMBINING LATIN SMALL LETTER LONG S
    (29, 230): 'z',  # COMBINING LATIN SMALL LETTER Z
    (240, 10): '',  # COMBINING HIGH MACRON WITH FIXED HEIGHT (PART-WIDTH)
    (240, 11): '',  # COMBINING MEDIUM-HIGH MACRON WITH FIXED HEIGHT (PART-WIDTH)
    (240, 12): '',  # COMBINING HIGH OVERLINE WITH FIXED HEIGHT (FULL-WIDTH)
    (240, 13): '',  # COMBINING MEDIUM-HIGH OVERLINE WITH FIXED HEIGHT (FULL-WIDTH)
    (240, 18): 'b',  # COMBINING LATIN SMALL LETTER B
    (240, 19): 'b',  # COMBINING LATIN LETTER SMALL CAPITAL B
    (240, 22): 'd',  # COMBINING LATIN LETTER SMALL CAPITAL D
    (240, 23): 'f',  # COMBINING LATIN SMALL LETTER F
    (240, 28): 'k',  # COMBINING LATIN LETTER SMALL CAPITAL K
    (240, 37): 'p',  # COMBINING LATIN SMALL LETTER P
    (240, 42): 't',  # COMBINING LATIN LETTER SMALL CAPITAL T
    (240, 43): 'y',  # COMBINING LATIN SMALL LETTER Y
    (240, 47): 'i',  # COMBINING LATIN SMALL LETTER DOTLESS I
    (240, 48): 'j',  # COMBINING LATIN SMALL LETTER J
    (240, 49): 'j',  # COMBINING LATIN SMALL LETTER DOTLESS J
    (240, 50): 'o',  # COMBINING LATIN LETTER SMALL O WITH STROKE
    (240, 51): 'q',  # COMBINING LATIN SMALL LETTER Q
    (240, 54): 'an',  # COMBINING LATIN SMALL LIGATURE AN
    (240, 56): 'ar',  # COMBINING LATIN SMALL LIGATURE AR
    (240, 58): 'an',  # COMBINING LATIN SMALL LIGATURE A SMALL CAPITAL N
    (240, 59): 't',  # COMBINING LATIN LETTER T ROTUNDA
    (240, 60): 'w',  # COMBINING LATIN SMALL LETTER W
    (240, 61): 'th',  # COMBINING LATIN SMALL LETTER THORN
    (240, 62): 'or',  # COMBINING LATIN SMALL LETTER O R ROTUNDA
    (240, 63): 'or',  # COMBINING LATIN SMALL LETTER O RUM
    (240, 64): 'r',  # COMBINING LATIN SMALL LETTER RUM
    (241, 48): 'ar',  # COMBINING LATIN SMALL LIGATURE A SMALL CAPITAL R
    (241, 53): 'e',  # COMBINING LATIN SMALL LETTER E WITH OGONEK
    (241, 54): 'e',  # COMBINING LATIN SMALL LETTER E WITH MACRON
    (241, 62): 'o',  # COMBINING LATIN SMALL LETTER O WITH OGONEK
    (241, 63): 'o',  # COMBINING LATIN SMALL LETTER O WITH MACRON
    (241, 83): 'ur',  # COMBINING ABBREVIATION MARK SUPERSCRIPT UR ROUND R FORM
    (241, 192): '',  # COMBINING ABBREVIATION MARK BAR ABOVE WITH DOT
    (241, 193): 'ra',  # COMBINING ABBREVIATION MARK SUPERSCRIPT RA OPEN A FORM WITH BAR ABOVE
    (241, 194): 'ur',  # COMBINING ABBREVIATION MARK SUPERSCRIPT UR LEMNISKATE FORM
    (241, 197): '',  # COMBINING CURL HIGH POSITION
    (241, 199): '',  # COMBINING ABBREVIATION MARK ZIGZAG ABOVE ANGLE FORM
    (241, 200): '',  # COMBINING ABBREVIATION MARK ZIGZAG ABOVE CURLY FORM
    (241, 202): '_',  # COMBINING DOT ABOVE HIGH POSITION
    (241, 204): '',  # COMBINING CURLY BAR ABOVE
    (241, 252): '',  # COMBINING TRIPLE BREVE BELOW
    (0, 71): 'G',  # LATIN CAPITAL LETTER G
    (0, 103): 'g',  # LATIN SMALL LETTER G
    (1, 32): 'G',  # LATIN CAPITAL LETTER G WITH DOT ABOVE
    (1, 33): 'g',  # LATIN SMALL LETTER G WITH DOT ABOVE
    (1, 228): 'G',  # LATIN CAPITAL LETTER G WITH STROKE
    (1, 229): 'g',  # LATIN SMALL LETTER G WITH STROKE
    (1, 244): 'G',  # LATIN CAPITAL LETTER G WITH ACUTE
    (1, 245): 'g',  # LATIN SMALL LETTER G WITH ACUTE
    (2, 97): 'g',  # LATIN SMALL LETTER SCRIPT G
    (2, 98): 'g',  # LATIN LETTER SMALL CAPITAL G
    (29, 121): 'g',  # LATIN SMALL LETTER INSULAR G
    (167, 125): 'G',  # LATIN CAPITAL LETTER INSULAR G
    (167, 126): 'G',  # LATIN CAPITAL LETTER TURNED INSULAR G
    (167, 127): 'g',  # LATIN SMALL LETTER TURNED INSULAR G
    (225, 1): 'G',  # LATIN CAPITAL LETTER G WITH DOT BELOW
    (229, 1): 'g',  # LATIN SMALL LETTER G WITH DOT BELOW
    (234, 208): 'gr',  # LATIN SMALL LIGATURE GR
    (234, 210): 'gp',  # LATIN SMALL LIGATURE GP
    (238, 209): 'gg',  # LATIN SMALL LIGATURE GG
    (238, 210): 'gd',  # LATIN SMALL LIGATURE GD
    (238, 211): 'gd',  # LATIN SMALL LIGATURE G D ROTUNDA
    (238, 212): 'geth',  # LATIN SMALL LIGATURE G ETH
    (238, 222): 'go',  # LATIN SMALL LIGATURE GO
    (238, 232): 'g',  # LATIN ENLARGED LETTER SMALL G
    (239, 32): 'G',  # LATIN LETTER SMALL CAPITAL G WITH DOT ABOVE
    (239, 39): 'G',  # LATIN LETTER SMALL CAPITAL G WITH DOT BELOW
    (241, 14): 'G',  # LATIN CAPITAL LETTER G SQUARE FORM
    (241, 150): 'g',  # LATIN SMALL LETTER G WITH CURL
    (242, 29): 'g',  # LATIN SMALL LETTER G WITH SEPARATE LOOPS
    (242, 30): 'g',  # LATIN SMALL LETTER CLOSED G WITH LARGE LOWER LOOP
    (242, 31): 'g',  # LATIN SMALL LETTER CLOSED G WITH SMALL LOWER LOOP
    (0, 38): '',  # AMPERSAND
    (0, 46): '',  # FULL STOP
    (0, 59): '',  # SEMICOLON
    (0, 94): '',  # CIRCUMFLEX ACCENT
    (0, 96): '',  # GRAVE ACCENT
    (0, 126): '',  # TILDE
    (0, 168): '',  # DIAERESIS
    (0, 175): '',  # MACRON
    (0, 180): '',  # ACUTE ACCENT
    (0, 184): '',  # CEDILLA
    (2, 188): '',  # MODIFIER LETTER APOSTROPHE
    (2, 200): '',  # MODIFIER LETTER VERTICAL LINE
    (2, 216): '',  # BREVE
    (2, 217): '',  # DOT ABOVE
    (2, 218): '',  # RING ABOVE
    (2, 219): '',  # OGONEK
    (2, 220): '',  # SMALL TILDE
    (2, 221): '',  # DOUBLE ACUTE ACCENT
    (22, 216): 'm',  # RUNIC MEDIEVAL LETTER M
    (32, 74): 'et',  # LATIN ABBREVIATION SIGN SMALL ET
    (33, 20): 'lb',  # L B BAR SYMBOL
    (34, 59): '',  # HOMOTHETIC
    (34, 72): '',  # ALMOST EQUAL TO
    (167, 62): 'C',  # LATIN CAPITAL LETTER REVERSED C WITH DOT
    (167, 63): 'c',  # LATIN SMALL LETTER REVERSED C WITH DOT
    (167, 74): 'O',  # LATIN CAPITAL LETTER O WITH LONG STROKE OVERLAY
    (167, 75): 'o',  # LATIN SMALL LETTER O WITH LONG STROKE OVERLAY
    (167, 92): 'R',  # LATIN CAPITAL LETTER RUM ROTUNDA
    (167, 93): 'r',  # LATIN SMALL LETTER RUM ROTUNDA
    (167, 106): 'ET',  # LATIN CAPITAL LETTER ET
    (167, 107): 'et',  # LATIN SMALL LETTER ET
    (167, 108): 'IS',  # LATIN CAPITAL LETTER IS
    (167, 109): 'is',  # LATIN SMALL LETTER IS
    (167, 110): 'CON',  # LATIN CAPITAL LETTER CON
    (167, 111): 'con',  # LATIN SMALL LETTER CON
    (167, 112): 'con',  # MODIFIER LETTER US
    (167, 120): 'um',  # LATIN SMALL LETTER UM
    (232, 163): 'autem',  # LATIN ABBREVIATION SIGN AUTEM
    (241, 66): 'ET',  # LATIN ABBREVIATION SIGN CAPITAL ET
    (241, 88): 'et',  # LATIN ABBREVIATION SIGN SMALL ET WITH STROKE
    (241, 89): 'de',  # LATIN ABBREVIATION SIGN SMALL DE
    (241, 165): 'CON',  # LATIN ABBREVIATION SIGN SPACING BASE-LINE CAPITAL US
    (241, 166): 'con',  # LATIN ABBREVIATION SIGN SPACING BASE-LINE US
    (241, 167): 'ET',  # LATIN ABBREVIATION SIGN CAPITAL ET WITH STROKE
    (241, 172): ';',  # LATIN ABBREVIATION SIGN SEMICOLON
    (0, 89): 'Y',  # LATIN CAPITAL LETTER Y
    (0, 121): 'y',  # LATIN SMALL LETTER Y
    (0, 221): 'Y',  # LATIN CAPITAL LETTER Y WITH ACUTE
    (0, 253): 'y',  # LATIN SMALL LETTER Y WITH ACUTE
    (0, 255): 'y',  # LATIN SMALL LETTER Y WITH DIAERESIS
    (1, 118): 'Y',  # LATIN CAPITAL LETTER Y WITH CIRCUMFLEX
    (1, 119): 'y',  # LATIN SMALL LETTER Y WITH CIRCUMFLEX
    (1, 120): 'Y',  # LATIN CAPITAL LETTER Y WITH DIAERESIS
    (2, 50): 'Y',  # LATIN CAPITAL LETTER Y WITH MACRON
    (2, 51): 'y',  # LATIN SMALL LETTER Y WITH MACRON
    (2, 143): 'y',  # LATIN LETTER SMALL CAPITAL Y
    (22, 163): 'Y',  # RUNIC LETTER YR
    (22, 164): 'Y',  # RUNIC LETTER Y
    (30, 142): 'Y',  # LATIN CAPITAL LETTER Y WITH DOT ABOVE
    (30, 143): 'y',  # LATIN SMALL LETTER Y WITH DOT ABOVE
    (30, 153): 'y',  # LATIN SMALL LETTER Y WITH RING ABOVE
    (30, 242): 'Y',  # LATIN CAPITAL LETTER Y WITH GRAVE
    (30, 243): 'y',  # LATIN SMALL LETTER Y WITH GRAVE
    (30, 244): 'Y',  # LATIN CAPITAL LETTER Y WITH DOT BELOW
    (30, 245): 'y',  # LATIN SMALL LETTER Y WITH DOT BELOW
    (30, 246): 'Y',  # LATIN CAPITAL LETTER Y WITH HOOK ABOVE
    (30, 247): 'y',  # LATIN SMALL LETTER Y WITH HOOK ABOVE
    (30, 254): 'Y',  # LATIN CAPITAL LETTER Y WITH LOOP
    (30, 255): 'y',  # LATIN SMALL LETTER Y WITH LOOP
    (167, 96): 'VY',  # LATIN CAPITAL LETTER VY
    (167, 97): 'vy',  # LATIN SMALL LETTER VY
    (227, 115): 'Y',  # LATIN CAPITAL LETTER Y WITH MACRON AND ACUTE
    (227, 117): 'Y',  # LATIN CAPITAL LETTER Y WITH MACRON AND BREVE
    (227, 118): 'Y',  # LATIN CAPITAL LETTER Y WITH BREVE
    (227, 124): 'Y',  # LATIN CAPITAL LETTER Y WITH DOUBLE ACUTE
    (227, 132): 'Y',  # LATIN CAPITAL LETTER Y WITH DOT ABOVE AND ACUTE
    (227, 133): 'Y',  # LATIN CAPITAL LETTER Y WITH CURL
    (231, 115): 'y',  # LATIN SMALL LETTER Y WITH MACRON AND ACUTE
    (231, 117): 'y',  # LATIN SMALL LETTER Y WITH MACRON AND BREVE
    (231, 118): 'y',  # LATIN SMALL LETTER Y WITH BREVE
    (231, 123): 'y',  # LATIN SMALL LETTER Y WITH BAR
    (231, 124): 'y',  # LATIN SMALL LETTER Y WITH DOUBLE ACUTE
    (231, 129): 'ye',  # LATIN SMALL LETTER Y WITH LATIN SMALL LETTER E ABOVE
    (231, 132): 'y',  # LATIN SMALL LETTER Y WITH DOT ABOVE AND ACUTE
    (231, 133): 'y',  # LATIN SMALL LETTER Y WITH CURL
    (235, 202): 'YY',  # LATIN CAPITAL LIGATURE YY WITH DOUBLE ACUTE
    (235, 203): 'yy',  # LATIN SMALL LIGATURE YY WITH DOUBLE ACUTE
    (235, 232): 'YY',  # LATIN CAPITAL LIGATURE YY WITH DIAERESIS
    (235, 233): 'yy',  # LATIN SMALL LIGATURE YY WITH DIAERESIS
    (238, 251): 'y',  # LATIN ENLARGED LETTER SMALL Y
    (242, 51): 'y',  # LATIN SMALL LETTER Y WITH RIGHT MAIN STROKE
    (0, 82): 'R',  # LATIN CAPITAL LETTER R
    (0, 114): 'r',  # LATIN SMALL LETTER R
    (1, 84): 'R',  # LATIN CAPITAL LETTER R WITH ACUTE
    (1, 85): 'r',  # LATIN SMALL LETTER R WITH ACUTE
    (1, 166): 'YR',  # LATIN LETTER YR
    (2, 124): 'r',  # LATIN SMALL LETTER R WITH LONG LEG
    (2, 128): 'r',  # LATIN LETTER SMALL CAPITAL R
    (30, 88): 'R',  # LATIN CAPITAL LETTER R WITH DOT ABOVE
    (30, 89): 'r',  # LATIN SMALL LETTER R WITH DOT ABOVE
    (30, 90): 'R',  # LATIN CAPITAL LETTER R WITH DOT BELOW
    (30, 91): 'r',  # LATIN SMALL LETTER R WITH DOT BELOW
    (33, 30): 'R',  # PRESCRIPTION TAKE
    (33, 31): 'R',  # RESPONSE
    (167, 90): 'R',  # LATIN CAPITAL LETTER R ROTUNDA
    (167, 91): 'r',  # LATIN SMALL LETTER R ROTUNDA
    (167, 117): 'r',  # LATIN SMALL LETTER RUM
    (167, 118): 'r',  # LATIN LETTER SMALL CAPITAL RUM
    (167, 130): 'R',  # LATIN CAPITAL LETTER INSULAR R
    (167, 131): 'r',  # LATIN SMALL LETTER INSULAR R
    (230, 163): 'r',  # LATIN SMALL LETTER R WITH RING BELOW
    (231, 193): 'r',  # LATIN SMALL LETTER R ROTUNDA WITH DOT BELOW
    (231, 228): 'r',  # LATIN SMALL LETTER R WITH LONG LEG AND STROKE THROUGH DESCENDER
    (232, 234): 're',  # LATIN SMALL LETTER R WITH LATIN SMALL LETTER E ABOVE
    (235, 185): 'r',  # LATIN SMALL LETTER R ROTUNDA WITH ACUTE
    (238, 243): 'r',  # LATIN ENLARGED LETTER SMALL R
    (239, 34): 'R',  # LATIN LETTER SMALL CAPITAL R WITH DOT ABOVE
    (239, 43): 'R',  # LATIN LETTER SMALL CAPITAL R WITH DOT BELOW
    (241, 155): 'r',  # LATIN SMALL LETTER R WITH FLOURISH
    (0, 69): 'E',  # LATIN CAPITAL LETTER E
    (0, 101): 'e',  # LATIN SMALL LETTER E
    (0, 200): 'E',  # LATIN CAPITAL LETTER E WITH GRAVE
    (0, 201): 'E',  # LATIN CAPITAL LETTER E WITH ACUTE
    (0, 202): 'E',  # LATIN CAPITAL LETTER E WITH CIRCUMFLEX
    (0, 203): 'E',  # LATIN CAPITAL LETTER E WITH DIAERESIS
    (0, 232): 'e',  # LATIN SMALL LETTER E WITH GRAVE
    (0, 233): 'e',  # LATIN SMALL LETTER E WITH ACUTE
    (0, 234): 'e',  # LATIN SMALL LETTER E WITH CIRCUMFLEX
    (0, 235): 'e',  # LATIN SMALL LETTER E WITH DIAERESIS
    (1, 18): 'E',  # LATIN CAPITAL LETTER E WITH MACRON
    (1, 19): 'e',  # LATIN SMALL LETTER E WITH MACRON
    (1, 20): 'E',  # LATIN CAPITAL LETTER E WITH BREVE
    (1, 21): 'e',  # LATIN SMALL LETTER E WITH BREVE
    (1, 22): 'E',  # LATIN CAPITAL LETTER E WITH DOT ABOVE
    (1, 23): 'e',  # LATIN SMALL LETTER E WITH DOT ABOVE
    (1, 24): 'E',  # LATIN CAPITAL LETTER E WITH OGONEK
    (1, 25): 'e',  # LATIN SMALL LETTER E WITH OGONEK
    (2, 89): 'e',  # LATIN SMALL LETTER SCHWA
    (29, 7): 'e',  # LATIN LETTER SMALL CAPITAL E
    (30, 22): 'E',  # LATIN CAPITAL LETTER E WITH MACRON AND ACUTE
    (30, 23): 'e',  # LATIN SMALL LETTER E WITH MACRON AND ACUTE
    (30, 184): 'E',  # LATIN CAPITAL LETTER E WITH DOT BELOW
    (30, 185): 'e',  # LATIN SMALL LETTER E WITH DOT BELOW
    (224, 153): 'E',  # LATIN CAPITAL LETTER E WITH OGONEK AND ACUTE
    (224, 183): 'E',  # LATIN CAPITAL LETTER E WITH MACRON AND BREVE
    (224, 188): 'E',  # LATIN CAPITAL LETTER E WITH OGONEK AND MACRON
    (224, 200): 'E',  # LATIN CAPITAL LETTER E WITH DOT ABOVE AND ACUTE
    (224, 209): 'E',  # LATIN CAPITAL LETTER E WITH DOUBLE ACUTE
    (224, 225): 'EA',  # LATIN CAPITAL LETTER E WITH LATIN SMALL LETTER A ABOVE
    (224, 232): 'E',  # LATIN CAPITAL LETTER E WITH OGONEK AND DOT BELOW
    (224, 233): 'E',  # LATIN CAPITAL LETTER E WITH CURL
    (224, 234): 'E',  # LATIN CAPITAL LETTER E WITH OGONEK AND DOUBLE ACUTE
    (224, 235): 'E',  # LATIN CAPITAL LETTER E WITH OGONEK AND DOT ABOVE
    (224, 236): 'E',  # LATIN CAPITAL LETTER E WITH OGONEK AND DOT ABOVE AND ACUTE
    (228, 152): 'e',  # LATIN SMALL LETTER E WITH DOT BELOW AND ACUTE
    (228, 153): 'e',  # LATIN SMALL LETTER E WITH OGONEK AND ACUTE
    (228, 159): 'e',  # LATIN SMALL LETTER E WITH OGONEK AND CIRCUMFLEX
    (228, 183): 'e',  # LATIN SMALL LETTER E WITH MACRON AND BREVE
    (228, 188): 'e',  # LATIN SMALL LETTER E WITH OGONEK AND MACRON
    (228, 200): 'e',  # LATIN SMALL LETTER E WITH DOT ABOVE AND ACUTE
    (228, 205): 'e',  # LATIN SMALL LETTER E WITH DIAERESIS AND MACRON
    (228, 207): 'e',  # LATIN SMALL LETTER E WITH RING ABOVE
    (228, 209): 'e',  # LATIN SMALL LETTER E WITH DOUBLE ACUTE
    (228, 225): 'ea',  # LATIN SMALL LETTER E WITH LATIN SMALL LETTER A ABOVE
    (228, 226): 'ei',  # LATIN SMALL LETTER E WITH LATIN SMALL LETTER I ABOVE
    (228, 227): 'ev',  # LATIN SMALL LETTER E WITH LATIN SMALL LETTER V ABOVE
    (228, 232): 'e',  # LATIN SMALL LETTER E WITH OGONEK AND DOT BELOW
    (228, 233): 'e',  # LATIN SMALL LETTER E WITH CURL
    (228, 234): 'e',  # LATIN SMALL LETTER E WITH OGONEK AND DOUBLE ACUTE
    (228, 235): 'e',  # LATIN SMALL LETTER E WITH OGONEK AND DOT ABOVE
    (228, 236): 'e',  # LATIN SMALL LETTER E WITH OGONEK AND DOT ABOVE AND ACUTE
    (232, 226): 'ee',  # LATIN SMALL LETTER E WITH LATIN SMALL LETTER E ABOVE
    (232, 227): 'eo',  # LATIN SMALL LETTER E WITH LATIN SMALL LETTER O ABOVE
    (234, 243): 'e',  # LATIN ENLARGED LETTER SMALL E WITH OGONEK
    (235, 189): 'ea',  # LATIN SMALL LETTER EA WITH CIRCUMFLEX
    (235, 190): 'eu',  # LATIN SMALL LETTER EU WITH CIRCUMFLEX
    (235, 242): 'E',  # LATIN CAPITAL LETTER E WITH OGONEK AND CURL
    (235, 243): 'e',  # LATIN SMALL LETTER E WITH OGONEK AND CURL
    (238, 199): 'ey',  # LATIN SMALL LIGATURE EY
    (238, 230): 'e',  # LATIN ENLARGED LETTER SMALL E
    (241, 10): 'E',  # LATIN CAPITAL LETTER E UNCIAL FORM
    (242, 23): 'E',  # LATIN CAPITAL LETTER CLOSED E UNCIAL FORM
    (242, 24): 'e',  # LATIN SMALL LETTER E UNCIAL FORM
    (242, 25): 'e',  # LATIN SMALL LETTER E EXTENDED BAR FORM
    (242, 26): 'e',  # LATIN SMALL LETTER E TALL FORM
    (0, 88): 'X',  # LATIN CAPITAL LETTER X
    (0, 120): 'x',  # LATIN SMALL LETTER X
    (2, 227): 'x',  # MODIFIER LETTER SMALL X
    (171, 87): 'x',  # LATIN SMALL LETTER X WITH LONG LEFT LEG
    (232, 189): 'x',  # LATIN SMALL LETTER X WITH SHORT SLASH ABOVE
    (232, 190): 'x',  # LATIN SMALL LETTER X WITH SHORT SLASH BELOW
    (232, 206): 'x',  # LATIN SMALL LETTER X WITH TWO SHORT SLASHES BELOW RIGHT
    (238, 250): 'x',  # LATIN ENLARGED LETTER SMALL X
    (239, 17): 'X',  # LATIN LETTER SMALL CAPITAL X
    (242, 50): 'x',  # LATIN SMALL LETTER X WITH LEFT DESCENDER
    (247, 179): 'X',  # LATIN CAPITAL LETTER X WITH HIGH OVERLINE (ABOVE CHARACTER)
    (0, 74): 'J',  # LATIN CAPITAL LETTER J
    (0, 106): 'j',  # LATIN SMALL LETTER J
    (2, 55): 'j',  # LATIN SMALL LETTER DOTLESS J
    (2, 72): 'J',  # LATIN CAPITAL LETTER J WITH STROKE
    (2, 73): 'j',  # LATIN SMALL LETTER J WITH STROKE
    (2, 95): 'j',  # LATIN SMALL LETTER DOTLESS J WITH STROKE
    (29, 10): 'j',  # LATIN LETTER SMALL CAPITAL J
    (225, 81): 'J',  # LATIN CAPITAL LETTER J WITH DOT BELOW
    (225, 82): 'J',  # LATIN CAPITAL LETTER J WITH HIGH OVERLINE (ABOVE CHARACTER)
    (225, 83): 'J',  # LATIN CAPITAL LETTER J WITH ACUTE
    (225, 84): 'J',  # LATIN CAPITAL LETTER J WITH HIGH MACRON (ABOVE CHARACTER)
    (225, 92): 'J',  # LATIN CAPITAL LETTER J WITH DOT ABOVE
    (225, 98): 'J',  # LATIN CAPITAL LETTER J WITH DOUBLE ACUTE
    (225, 99): 'J',  # LATIN CAPITAL LETTER J WITH CURL
    (229, 81): 'j',  # LATIN SMALL LETTER J WITH DOT BELOW
    (229, 82): 'j',  # LATIN SMALL LETTER J WITH MEDIUM-HIGH OVERLINE (ABOVE CHARACTER)
    (229, 83): 'j',  # LATIN SMALL LETTER J WITH ACUTE
    (229, 84): 'j',  # LATIN SMALL LETTER J WITH MEDIUM-HIGH MACRON (ABOVE CHARACTER)
    (229, 98): 'j',  # LATIN SMALL LETTER J WITH DOUBLE ACUTE
    (229, 99): 'j',  # LATIN SMALL LETTER J WITH CURL
    (232, 162): 'j',  # LATIN SMALL LETTER J WITH TWO STROKES
    (232, 231): 'je',  # LATIN SMALL LETTER J WITH LATIN SMALL LETTER E ABOVE
    (235, 226): 'J',  # LATIN CAPITAL LETTER J WITH DIAERESIS
    (235, 227): 'j',  # LATIN SMALL LETTER J WITH DIAERESIS
    (238, 235): 'j',  # LATIN ENLARGED LETTER SMALL J
    (238, 254): 'j',  # LATIN ENLARGED LETTER SMALL DOTLESS J
    (0, 80): 'P',  # LATIN CAPITAL LETTER P
    (0, 112): 'p',  # LATIN SMALL LETTER P
    (29, 24): 'p',  # LATIN LETTER SMALL CAPITAL P
    (30, 84): 'P',  # LATIN CAPITAL LETTER P WITH ACUTE
    (30, 85): 'p',  # LATIN SMALL LETTER P WITH ACUTE
    (30, 86): 'P',  # LATIN CAPITAL LETTER P WITH DOT ABOVE
    (30, 87): 'p',  # LATIN SMALL LETTER P WITH DOT ABOVE
    (167, 80): 'P',  # LATIN CAPITAL LETTER P WITH STROKE THROUGH DESCENDER
    (167, 81): 'p',  # LATIN SMALL LETTER P WITH STROKE THROUGH DESCENDER
    (167, 82): 'P',  # LATIN CAPITAL LETTER P WITH FLOURISH
    (167, 83): 'p',  # LATIN SMALL LETTER P WITH FLOURISH
    (167, 84): 'P',  # LATIN CAPITAL LETTER P WITH SQUIRREL TAIL
    (167, 85): 'p',  # LATIN SMALL LETTER P WITH SQUIRREL TAIL
    (167, 252): 'P',  # LATIN EPIGRAPHIC LETTER REVERSED P
    (226, 104): 'P',  # LATIN CAPITAL LETTER P WITH DOUBLE ACUTE
    (226, 109): 'P',  # LATIN CAPITAL LETTER P WITH DOT BELOW
    (230, 101): 'p',  # LATIN SMALL LETTER P WITH MACRON
    (230, 104): 'p',  # LATIN SMALL LETTER P WITH DOUBLE ACUTE
    (230, 109): 'p',  # LATIN SMALL LETTER P WITH DOT BELOW
    (235, 207): 'P',  # LATIN LETTER SMALL CAPITAL P WITH DOT ABOVE
    (235, 230): 'PP',  # LATIN CAPITAL LIGATURE PP WITH DIAERESIS
    (235, 231): 'pp',  # LATIN SMALL LIGATURE PP WITH DIAERESIS
    (238, 214): 'pp',  # LATIN SMALL LIGATURE PP
    (238, 215): 'pp',  # LATIN SMALL LIGATURE PP WITH FLOURISH
    (238, 221): 'PP',  # LATIN CAPITAL LIGATURE PP
    (238, 241): 'p',  # LATIN ENLARGED LETTER SMALL P
    (0, 78): 'N',  # LATIN CAPITAL LETTER N
    (0, 110): 'n',  # LATIN SMALL LETTER N
    (0, 209): 'N',  # LATIN CAPITAL LETTER N WITH TILDE
    (0, 241): 'n',  # LATIN SMALL LETTER N WITH TILDE
    (1, 67): 'N',  # LATIN CAPITAL LETTER N WITH ACUTE
    (1, 68): 'n',  # LATIN SMALL LETTER N WITH ACUTE
    (1, 74): 'N',  # LATIN CAPITAL LETTER ENG
    (1, 75): 'n',  # LATIN SMALL LETTER ENG
    (1, 158): 'n',  # LATIN SMALL LETTER N WITH LONG RIGHT LEG
    (2, 114): 'n',  # LATIN SMALL LETTER N WITH LEFT HOOK
    (2, 116): 'n',  # LATIN LETTER SMALL CAPITAL N
    (30, 68): 'N',  # LATIN CAPITAL LETTER N WITH DOT ABOVE
    (30, 69): 'n',  # LATIN SMALL LETTER N WITH DOT ABOVE
    (30, 70): 'N',  # LATIN CAPITAL LETTER N WITH DOT BELOW
    (30, 71): 'n',  # LATIN SMALL LETTER N WITH DOT BELOW
    (167, 116): 'n',  # LATIN SMALL LETTER NUM
    (225, 220): 'N',  # LATIN CAPITAL LETTER N WITH HIGH MACRON (ABOVE CHARACTER)
    (229, 215): 'n',  # LATIN SMALL LETTER N WITH CIRCUMFLEX
    (229, 220): 'n',  # LATIN SMALL LETTER N WITH MEDIUM-HIGH MACRON (ABOVE CHARACTER)
    (229, 238): 'n',  # LATIN SMALL LETTER N WITH RING BELOW
    (231, 178): 'n',  # LATIN SMALL LETTER N WITH BAR
    (238, 213): 'ns',  # LATIN SMALL LIGATURE SMALL CAPITAL N LONG S
    (238, 239): 'n',  # LATIN ENLARGED LETTER SMALL N
    (239, 33): 'N',  # LATIN LETTER SMALL CAPITAL N WITH DOT ABOVE
    (239, 42): 'N',  # LATIN LETTER SMALL CAPITAL N WITH DOT BELOW
    (241, 154): 'n',  # LATIN SMALL LETTER N WITH FLOURISH
    (242, 40): 'n',  # LATIN SMALL LETTER N WITH RIGHT DESCENDER
    (242, 41): 'N',  # LATIN CAPITAL LETTER N WITH RIGHT DESCENDER
    (242, 42): 'N',  # LATIN LETTER SMALL CAPITAL N WITH RIGHT DESCENDER
    (242, 43): 'N',  # LATIN LETTER SMALL CAPITAL N WITH LEFT DESCENDER
    (0, 35): '',  # NUMBER SIGN
    (0, 36): '',  # DOLLAR SIGN
    (0, 37): '',  # PERCENT SIGN
    (0, 42): '',  # ASTERISK
    (0, 43): '',  # PLUS SIGN
    (0, 61): '',  # EQUALS SIGN
    (0, 64): '',  # COMMERCIAL AT
    (0, 162): '',  # CENT SIGN
    (0, 163): '',  # POUND SIGN
    (0, 164): '',  # CURRENCY SIGN
    (0, 165): '',  # YEN SIGN
    (0, 167): '',  # SECTION SIGN
    (0, 169): '',  # COPYRIGHT SIGN
    (0, 172): '',  # NOT SIGN
    (0, 174): '',  # REGISTERED SIGN
    (0, 176): '',  # DEGREE SIGN
    (0, 177): '',  # PLUS-MINUS SIGN
    (0, 181): '',  # MICRO SIGN
    (0, 182): '',  # PILCROW SIGN
    (0, 215): '',  # MULTIPLICATION SIGN
    (0, 247): '',  # DIVISION SIGN
    (32, 32): '',  # DAGGER
    (32, 33): '',  # DOUBLE DAGGER
    (32, 48): '',  # PER MILLE SIGN
    (32, 59): '',  # REFERENCE MARK
    (32, 66): '',  # ASTERISM
    (32, 75): '',  # REVERSED PILCROW SIGN
    (32, 92): '',  # DOTTED CROSS
    (32, 176): '',  # GERMAN PENNY SIGN
    (33, 8): '',  # SCRUPLE
    (33, 37): '',  # OUNCE SIGN
    (34, 18): '',  # MINUS
    (34, 30): '',  # INFINITY
    (34, 39): '',  # LOGICAL AND
    (34, 96): '',  # NOT EQUAL TO
    (39, 29): '',  # LATIN CROSS
    (39, 102): '',  # FLORAL HEART
    (39, 103): '',  # ROTATED FLORAL HEART BULLET
    (241, 189): '0',  # SMALL BASE LINE ZERO SIGN
    (241, 210): '_',  # TRIPLE DAGGER
    (242, 224): '_',  # LATIN AS LIBRALIS SIGN
    (242, 226): 'X',  # LATIN SMALL CAPITAL LETTER X WITH BAR
    (242, 227): 'Y',  # LATIN SMALL CAPITAL LETTER Y WITH BAR
    (242, 228): 'D',  # LATIN SMALL CAPITAL LETTER D WITH SLASH
    (242, 230): '_',  # PHARMACEUTICAL DRAM SIGN
    (242, 231): '_',  # ECU SIGN
    (242, 232): 'F',  # FLOREN SIGN WITH LOOP
    (242, 233): '_',  # GROSCHEN SIGN
    (242, 234): '£',  # DUTCH LIBRA SIGN
    (242, 235): '£',  # FRENCH LIBRA SIGN
    (242, 236): '£',  # ITALIAN LIBRA SIGN
    (242, 237): '£',  # FLEMISH LIBRA SIGN
    (242, 238): '_',  # LIRA NUOVA SIGN
    (242, 239): '_',  # LIRA STERLINA SIGN
    (242, 240): 'm',  # OLD MARK SIGN
    (242, 241): 'm',  # OLD FLOURISH MARK SIGN
    (242, 242): 'm',  # MARKED SMALL LETTER M SIGN
    (242, 243): 'f',  # FLOURISHED SMALL LETTER M SIGN
    (242, 244): '_',  # PHARMACEUTICAL OBOLUS SIGN
    (242, 245): '_',  # PENNING SIGN
    (242, 246): '_',  # OLD REICHSTALER SIGN
    (242, 247): '_',  # GERMAN SCHILLING SIGN
    (242, 248): '_',  # GERMAN SCRIPT SCHILLING SIGN
    (242, 249): '_',  # SCUDI SIGN
    (242, 250): '_',  # KRONE SIGN
    (242, 251): '_',  # HELBING SIGN
    (242, 253): '_',  # SCRIPT OUNCE SIGN
    (257, 144): '',  # ROMAN SEXTANS SIGN
    (257, 145): '',  # ROMAN UNCIA SIGN
    (257, 146): '',  # ROMAN SEMIUNCIA SIGN
    (257, 147): '',  # ROMAN SEXTULA SIGN
    (257, 148): '',  # ROMAN DIMIDIA SEXTULA SIGN
    (257, 149): '',  # ROMAN SILIQUA SIGN
    (257, 150): '',  # LATIN CAPITAL LETTER X WITH BAR
    (257, 151): '',  # ROMAN QUINARIUS SIGN
    (257, 152): '',  # SESTERTIA SIGN
    (257, 153): '',  # ROMAN DUPONDIUS SIGN
    (257, 154): '',  # ROMAN AS SIGN
    (0, 48): '0',  # DIGIT ZERO
    (0, 49): '1',  # DIGIT ONE
    (0, 50): '2',  # DIGIT TWO
    (0, 51): '3',  # DIGIT THREE
    (0, 52): '4',  # DIGIT FOUR
    (0, 53): '5',  # DIGIT FIVE
    (0, 54): '6',  # DIGIT SIX
    (0, 55): '7',  # DIGIT SEVEN
    (0, 56): '8',  # DIGIT EIGHT
    (0, 57): '9',  # DIGIT NINE
    (0, 178): '2',  # SUPERSCRIPT TWO
    (0, 179): '3',  # SUPERSCRIPT THREE
    (0, 185): '1',  # SUPERSCRIPT ONE
    (0, 188): '0.25',  # VULGAR FRACTION ONE QUARTER
    (0, 189): '0.5',  # VULGAR FRACTION ONE HALF
    (0, 190): '0.75',  # VULGAR FRACTION THREE QUARTERS
    (29, 53): 'I',  # MODIFIER CAPITAL LETTER I
    (32, 112): '0',  # SUPERSCRIPT ZERO
    (32, 116): '4',  # SUPERSCRIPT FOUR
    (32, 117): '5',  # SUPERSCRIPT FIVE
    (32, 118): '6',  # SUPERSCRIPT SIX
    (32, 119): '7',  # SUPERSCRIPT SEVEN
    (32, 120): '8',  # SUPERSCRIPT EIGHT
    (32, 121): '9',  # SUPERSCRIPT NINE
    (32, 128): '0',  # SUBSCRIPT ZERO
    (32, 129): '1',  # SUBSCRIPT ONE
    (32, 130): '2',  # SUBSCRIPT TWO
    (32, 131): '3',  # SUBSCRIPT THREE
    (32, 132): '4',  # SUBSCRIPT FOUR
    (32, 133): '5',  # SUBSCRIPT FIVE
    (32, 134): '6',  # SUBSCRIPT SIX
    (32, 135): '7',  # SUBSCRIPT SEVEN
    (32, 136): '8',  # SUBSCRIPT EIGHT
    (32, 137): '9',  # SUBSCRIPT NINE
    (33, 128): 'CD',  # ROMAN NUMERAL ONE THOUSAND C D
    (33, 129): 'DD',  # ROMAN NUMERAL FIVE THOUSAND
    (33, 130): 'CDCD',  # ROMAN NUMERAL TEN THOUSAND
    (33, 131): 'C',  # ROMAN NUMERAL REVERSED ONE HUNDRED
    (241, 190): 'V',  # MODIFIER CAPITAL LETTER V
    (241, 191): 'X',  # MODIFIER CAPITAL LETTER X
    (242, 63): 'C',  # ROMAN NUMERAL REVERSED ONE HUNDRED WITH OVERLINE
    (0, 72): 'H',  # LATIN CAPITAL LETTER H
    (0, 104): 'h',  # LATIN SMALL LETTER H
    (1, 39): 'h',  # LATIN SMALL LETTER H WITH STROKE
    (1, 149): 'hv',  # LATIN SMALL LETTER HV
    (1, 246): 'HW',  # LATIN CAPITAL LETTER HWAIR
    (2, 102): 'h',  # LATIN SMALL LETTER H WITH HOOK
    (2, 156): 'h',  # LATIN LETTER SMALL CAPITAL H
    (30, 34): 'h',  # LATIN SMALL LETTER H WITH DOT ABOVE
    (30, 35): 'H',  # LATIN CAPITAL LETTER H WITH DOT ABOVE
    (30, 36): 'H',  # LATIN CAPITAL LETTER H WITH DOT BELOW
    (30, 37): 'h',  # LATIN SMALL LETTER H WITH DOT BELOW
    (44, 117): 'H',  # LATIN CAPITAL LETTER HALF H
    (44, 118): 'h',  # LATIN SMALL LETTER HALF H
    (225, 22): 'H',  # LATIN CAPITAL LETTER H WITH ACUTE
    (229, 22): 'h',  # LATIN SMALL LETTER H WITH ACUTE
    (229, 23): 'h',  # LATIN SMALL LETTER H WITH MEDIUM-HIGH OVERLINE (ACROSS ASCENDER)
    (231, 199): 'hs',  # LATIN SMALL LIGATURE H AND LONG S WITH STROKE
    (232, 194): 'HR',  # LATIN CAPITAL LETTER H LIGATED WITH ARM OF LATIN SMALL LETTER R
    (232, 195): 'hr',  # LATIN SMALL LETTER H LIGATED WITH ARM OF LATIN SMALL LETTER R
    (235, 173): 'hs',  # LATIN SMALL LIGATURE H AND LONG S
    (235, 218): 'H',  # LATIN LETTER SMALL CAPITAL H WITH DOT ABOVE
    (238, 233): 'h',  # LATIN ENLARGED LETTER SMALL H
    (241, 16): 'H',  # LATIN CAPITAL LETTER UNCIAL H
    (242, 58): 'h',  # LATIN SMALL LETTER H WITH RIGHT DESCENDER
    (0, 76): 'L',  # LATIN CAPITAL LETTER L
    (0, 108): 'l',  # LATIN SMALL LETTER L
    (1, 57): 'L',  # LATIN CAPITAL LETTER L WITH ACUTE
    (1, 58): 'l',  # LATIN SMALL LETTER L WITH ACUTE
    (1, 65): 'L',  # LATIN CAPITAL LETTER L WITH STROKE
    (1, 66): 'l',  # LATIN SMALL LETTER L WITH STROKE
    (1, 154): 'l',  # LATIN SMALL LETTER L WITH BAR
    (2, 159): 'l',  # LATIN LETTER SMALL CAPITAL L
    (30, 54): 'L',  # LATIN CAPITAL LETTER L WITH DOT BELOW
    (30, 55): 'l',  # LATIN SMALL LETTER L WITH DOT BELOW
    (30, 250): 'LL',  # LATIN CAPITAL LETTER MIDDLE-WELSH LL
    (30, 251): 'll',  # LATIN SMALL LETTER MIDDLE-WELSH LL
    (167, 70): 'L',  # LATIN CAPITAL LETTER BROKEN L
    (167, 71): 'l',  # LATIN SMALL LETTER BROKEN L
    (167, 72): 'L',  # LATIN CAPITAL LETTER L WITH HIGH STROKE
    (167, 73): 'l',  # LATIN SMALL LETTER L WITH HIGH STROKE
    (167, 114): 'l',  # LATIN SMALL LETTER LUM
    (167, 128): 'L',  # LATIN CAPITAL LETTER TURNED L
    (167, 129): 'l',  # LATIN SMALL LETTER TURNED L
    (225, 158): 'L',  # LATIN CAPITAL LETTER L WITH DOT ABOVE
    (229, 140): 'l',  # LATIN SMALL LETTER L WITH HIGH OVERLINE (ABOVE CHARACTER)
    (229, 150): 'l',  # LATIN SMALL LETTER L WITH HIGH MACRON (ABOVE CHARACTER)
    (229, 158): 'l',  # LATIN SMALL LETTER L WITH DOT ABOVE
    (229, 164): 'l',  # LATIN SMALL LETTER L WITH RING BELOW
    (229, 177): 'l',  # LATIN SMALL LETTER L WITH MEDIUM-HIGH OVERLINE (ACROSS ASCENDER)
    (235, 220): 'L',  # LATIN LETTER SMALL CAPITAL L WITH DOT ABOVE
    (238, 237): 'l',  # LATIN ENLARGED LETTER SMALL L
    (239, 40): 'L',  # LATIN LETTER SMALL CAPITAL L WITH DOT BELOW
    (242, 34): 'l',  # LATIN SMALL LETTER L DESCENDING
    (244, 249): 'll',  # LATIN SMALL LIGATURE LL
    (247, 180): 'L',  # LATIN CAPITAL LETTER L WITH HIGH OVERLINE (ABOVE CHARACTER)
    (0, 70): 'F',  # LATIN CAPITAL LETTER F
    (0, 102): 'f',  # LATIN SMALL LETTER F
    (22, 160): 'F',  # RUNIC LETTER FEHU FEOH FE F
    (30, 30): 'F',  # LATIN CAPITAL LETTER F WITH DOT ABOVE
    (30, 31): 'f',  # LATIN SMALL LETTER F WITH DOT ABOVE
    (33, 50): 'F',  # TURNED CAPITAL F
    (33, 78): 'f',  # TURNED SMALL F
    (167, 48): 'f',  # LATIN LETTER SMALL CAPITAL F
    (167, 123): 'F',  # LATIN CAPITAL LETTER INSULAR F
    (167, 124): 'f',  # LATIN SMALL LETTER INSULAR F
    (167, 251): 'F',  # LATIN EPIGRAPHIC LETTER REVERSED F
    (224, 238): 'F',  # LATIN CAPITAL LETTER F WITH DOT BELOW
    (224, 240): 'F',  # LATIN CAPITAL LETTER F WITH ACUTE
    (227, 229): 'F',  # LATIN CAPITAL LETTER INSULAR F WITH DOT BELOW
    (228, 238): 'f',  # LATIN SMALL LETTER F WITH DOT BELOW
    (228, 240): 'f',  # LATIN SMALL LETTER F WITH ACUTE
    (231, 229): 'f',  # LATIN SMALL LETTER INSULAR F WITH DOT BELOW
    (235, 179): 'F',  # LATIN CAPITAL LETTER INSULAR F WITH ACUTE
    (235, 180): 'f',  # LATIN SMALL LETTER INSULAR F WITH ACUTE
    (235, 211): 'F',  # LATIN CAPITAL LETTER INSULAR F WITH DOT ABOVE
    (235, 212): 'f',  # LATIN SMALL LETTER INSULAR F WITH DOT ABOVE
    (235, 213): 'f',  # LATIN SMALL LETTER SEMI-CLOSED INSULAR F WITH DOT ABOVE
    (235, 214): 'f',  # LATIN SMALL LETTER CLOSED INSULAR F WITH DOT ABOVE
    (235, 215): 'F',  # LATIN LETTER SMALL CAPITAL F WITH DOT ABOVE
    (238, 200): 'fa',  # LATIN SMALL LIGATURE F A WITH DIAERESIS
    (238, 201): 'fj',  # LATIN SMALL LIGATURE FJ
    (238, 202): 'fr',  # LATIN SMALL LIGATURE FR
    (238, 203): 'ft',  # LATIN SMALL LIGATURE FT
    (238, 204): 'fu',  # LATIN SMALL LIGATURE F U WITH DIAERESIS
    (238, 205): 'fy',  # LATIN SMALL LIGATURE FY
    (238, 206): 'fft',  # LATIN SMALL LIGATURE FFT
    (238, 207): 'ffy',  # LATIN SMALL LIGATURE FFY
    (238, 208): 'fty',  # LATIN SMALL LIGATURE FTY
    (238, 231): 'f',  # LATIN ENLARGED LETTER SMALL F
    (238, 255): 'f',  # LATIN ENLARGED LETTER SMALL INSULAR F
    (241, 148): 'f',  # LATIN SMALL LETTER F WITH CURL
    (241, 188): 'fo',  # LATIN SMALL LIGATURE F O WITH DIAERESIS
    (242, 7): 'f',  # LATIN SMALL LETTER CLOSED INSULAR F
    (242, 27): 'f',  # LATIN SMALL LETTER SEMI-CLOSED INSULAR F
    (242, 28): 'f',  # LATIN SMALL LETTER INSULAR F WITH DOTTED HOOKS
    (251, 0): 'ff',  # LATIN SMALL LIGATURE FF
    (251, 1): 'fi',  # LATIN SMALL LIGATURE FI
    (251, 2): 'fl',  # LATIN SMALL LIGATURE FL
    (251, 3): 'ffi',  # LATIN SMALL LIGATURE FFI
    (251, 4): 'ffl',  # LATIN SMALL LIGATURE FFL
    (0, 77): 'M',  # LATIN CAPITAL LETTER M
    (0, 109): 'm',  # LATIN SMALL LETTER M
    (1, 156): 'M',  # LATIN CAPITAL LETTER TURNED M
    (2, 111): 'm',  # LATIN SMALL LETTER TURNED M
    (29, 13): 'm',  # LATIN LETTER SMALL CAPITAL M
    (30, 62): 'M',  # LATIN CAPITAL LETTER M WITH ACUTE
    (30, 63): 'm',  # LATIN SMALL LETTER M WITH ACUTE
    (30, 64): 'M',  # LATIN CAPITAL LETTER M WITH DOT ABOVE
    (30, 65): 'm',  # LATIN SMALL LETTER M WITH DOT ABOVE
    (30, 66): 'M',  # LATIN CAPITAL LETTER M WITH DOT BELOW
    (30, 67): 'm',  # LATIN SMALL LETTER M WITH DOT BELOW
    (167, 115): 'm',  # LATIN SMALL LETTER MUM
    (167, 253): 'M',  # LATIN EPIGRAPHIC LETTER INVERTED M
    (167, 255): 'M',  # LATIN EPIGRAPHIC LETTER ARCHAIC M
    (225, 184): 'M',  # LATIN CAPITAL LETTER M WITH HIGH MACRON (ABOVE CHARACTER)
    (225, 210): 'M',  # LATIN CAPITAL LETTER M WITH HIGH OVERLINE (ABOVE CHARACTER)
    (229, 184): 'm',  # LATIN SMALL LETTER M WITH MEDIUM-HIGH MACRON (ABOVE CHARACTER)
    (229, 197): 'm',  # LATIN SMALL LETTER M WITH RING BELOW
    (229, 210): 'm',  # LATIN SMALL LETTER M WITH MEDIUM-HIGH OVERLINE (ABOVE CHARACTER)
    (232, 232): 'me',  # LATIN SMALL LETTER M WITH LATIN SMALL LETTER E ABOVE
    (235, 181): 'M',  # LATIN CAPITAL LETTER UNCIAL M WITH ACUTE
    (235, 182): 'm',  # LATIN SMALL LETTER UNCIAL M WITH ACUTE
    (235, 221): 'M',  # LATIN LETTER SMALL CAPITAL M WITH DOT ABOVE
    (238, 238): 'm',  # LATIN ENLARGED LETTER SMALL M
    (239, 41): 'M',  # LATIN LETTER SMALL CAPITAL M WITH DOT BELOW
    (241, 26): 'M',  # LATIN CAPITAL LETTER UNCIAL M
    (242, 35): 'm',  # LATIN SMALL LETTER M WITH RIGHT DESCENDER
    (242, 36): 'M',  # LATIN CAPITAL LETTER UNCIAL M WITH RIGHT DESCENDER
    (242, 37): 'm',  # LATIN MEDIUSCULE LETTER M UNCIAL FORM
    (242, 38): 'm',  # LATIN SMALL LETTER UNCIAL M WITH RIGH DESCENDER
    (242, 60): 'm',  # LATIN SMALL LETTER M UNCIAL FORM
    (242, 61): 'm',  # LATIN SMALL LETTER M UNCIAL FORM WITH RIGHT DESCENDER
    (242, 62): 'm',  # LATIN SMALL LETTER M UNCIAL FORM WITH ACUTE ACCENT
    (0, 84): 'T',  # LATIN CAPITAL LETTER T
    (0, 116): 't',  # LATIN SMALL LETTER T
    (3, 152): 'TH',  # GREEK CAPITAL LETTER THETA
    (3, 184): 'th',  # GREEK SMALL LETTER THETA
    (29, 27): 't',  # LATIN LETTER SMALL CAPITAL T
    (30, 106): 'T',  # LATIN CAPITAL LETTER T WITH DOT ABOVE
    (30, 107): 't',  # LATIN SMALL LETTER T WITH DOT ABOVE
    (30, 108): 'T',  # LATIN CAPITAL LETTER T WITH DOT BELOW
    (30, 109): 't',  # LATIN SMALL LETTER T WITH DOT BELOW
    (167, 119): 't',  # LATIN SMALL LETTER TUM
    (167, 134): 'T',  # LATIN CAPITAL LETTER INSULAR T
    (167, 135): 't',  # LATIN SMALL LETTER INSULAR T
    (226, 226): 'T',  # LATIN CAPITAL LETTER T WITH ACUTE
    (226, 238): 'T',  # LATIN CAPITAL LETTER T WITH OGONEK
    (230, 226): 't',  # LATIN SMALL LETTER T WITH ACUTE
    (230, 238): 't',  # LATIN SMALL LETTER T WITH OGONEK
    (238, 216): 'tr',  # LATIN SMALL LIGATURE TR
    (238, 217): 'tt',  # LATIN SMALL LIGATURE TT
    (238, 218): 'tt',  # LATIN SMALL LIGATURE T ROTUNDA T ROTUNDA
    (238, 219): 'ty',  # LATIN SMALL LIGATURE TY
    (238, 220): 'tz',  # LATIN SMALL LIGATURE TZ
    (238, 245): 't',  # LATIN ENLARGED LETTER SMALL T
    (239, 36): 'T',  # LATIN LETTER SMALL CAPITAL T WITH DOT ABOVE
    (239, 45): 'T',  # LATIN LETTER SMALL CAPITAL T WITH DOT BELOW
    (241, 153): 't',  # LATIN SMALL LETTER T WITH CURL
    (0, 73): 'I',  # LATIN CAPITAL LETTER I
    (0, 105): 'i',  # LATIN SMALL LETTER I
    (0, 204): 'I',  # LATIN CAPITAL LETTER I WITH GRAVE
    (0, 205): 'I',  # LATIN CAPITAL LETTER I WITH ACUTE
    (0, 206): 'I',  # LATIN CAPITAL LETTER I WITH CIRCUMFLEX
    (0, 207): 'I',  # LATIN CAPITAL LETTER I WITH DIAERESIS
    (0, 236): 'i',  # LATIN SMALL LETTER I WITH GRAVE
    (0, 237): 'i',  # LATIN SMALL LETTER I WITH ACUTE
    (0, 238): 'i',  # LATIN SMALL LETTER I WITH CIRCUMFLEX
    (0, 239): 'i',  # LATIN SMALL LETTER I WITH DIAERESIS
    (1, 42): 'I',  # LATIN CAPITAL LETTER I WITH MACRON
    (1, 43): 'i',  # LATIN SMALL LETTER I WITH MACRON
    (1, 44): 'I',  # LATIN CAPITAL LETTER I WITH BREVE
    (1, 45): 'i',  # LATIN SMALL LETTER I WITH BREVE
    (1, 46): 'I',  # LATIN CAPITAL LETTER I WITH OGONEK
    (1, 47): 'i',  # LATIN SMALL LETTER I WITH OGONEK
    (1, 48): 'I',  # LATIN CAPITAL LETTER I WITH DOT ABOVE
    (1, 49): 'i',  # LATIN SMALL LETTER DOTLESS I
    (1, 50): 'IJ',  # LATIN CAPITAL LIGATURE IJ
    (1, 51): 'ij',  # LATIN SMALL LIGATURE IJ
    (2, 104): 'i',  # LATIN SMALL LETTER I WITH STROKE
    (2, 106): 'i',  # LATIN LETTER SMALL CAPITAL I
    (30, 200): 'I',  # LATIN CAPITAL LETTER I WITH HOOK ABOVE
    (30, 201): 'i',  # LATIN SMALL LETTER I WITH HOOK ABOVE
    (30, 202): 'I',  # LATIN CAPITAL LETTER I WITH DOT BELOW
    (30, 203): 'i',  # LATIN SMALL LETTER I WITH DOT BELOW
    (167, 254): 'I',  # LATIN EPIGRAPHIC LETTER I LONGA
    (225, 42): 'I',  # LATIN CAPITAL LETTER I WITH CURL
    (225, 53): 'I',  # LATIN CAPITAL LETTER I WITH MACRON AND ACUTE
    (225, 55): 'I',  # LATIN CAPITAL LETTER I WITH MACRON AND BREVE
    (225, 67): 'I',  # LATIN CAPITAL LETTER I WITH DOUBLE ACUTE
    (225, 80): 'I',  # LATIN CAPITAL LETTER I WITH HIGH OVERLINE (ABOVE CHARACTER)
    (229, 42): 'i',  # LATIN SMALL LETTER I WITH CURL
    (229, 53): 'i',  # LATIN SMALL LETTER I WITH MACRON AND ACUTE
    (229, 55): 'i',  # LATIN SMALL LETTER I WITH MACRON AND BREVE
    (229, 67): 'i',  # LATIN SMALL LETTER I WITH DOUBLE ACUTE
    (229, 72): 'i',  # LATIN SMALL LETTER I WITH INVERTED BREVE BELOW
    (229, 74): 'ie',  # LATIN SMALL LETTER I WITH LATIN SMALL LETTER E ABOVE
    (229, 75): 'iv',  # LATIN SMALL LETTER I WITH LATIN SMALL LETTER V ABOVE
    (229, 80): 'i',  # LATIN SMALL LETTER I WITH MEDIUM-HIGH OVERLINE (ABOVE CHARACTER)
    (232, 161): 'i',  # LATIN SMALL LETTER I WITH TWO STROKES
    (232, 221): 'i',  # LATIN SMALL LETTER DOTLESS I WITH OGONEK
    (232, 228): 'ia',  # LATIN SMALL LETTER I WITH LATIN SMALL LETTER A ABOVE
    (232, 229): 'io',  # LATIN SMALL LETTER I WITH LATIN SMALL LETTER O ABOVE
    (232, 230): 'iu',  # LATIN SMALL LETTER I WITH LATIN SMALL LETTER U ABOVE
    (235, 246): 'I',  # LATIN CAPITAL LETTER I WITH DOT ABOVE AND ACUTE
    (235, 247): 'i',  # LATIN SMALL LETTER I WITH DOT ABOVE AND ACUTE
    (238, 234): 'i',  # LATIN ENLARGED LETTER SMALL I
    (238, 253): 'i',  # LATIN ENLARGED LETTER SMALL DOTLESS I
    (242, 32): 'i',  # LATIN SMALL LETTER LONG I
    (0, 87): 'W',  # LATIN CAPITAL LETTER W
    (0, 119): 'w',  # LATIN SMALL LETTER W
    (1, 116): 'W',  # LATIN CAPITAL LETTER W WITH CIRCUMFLEX
    (1, 117): 'w',  # LATIN SMALL LETTER W WITH CIRCUMFLEX
    (22, 165): 'W',  # RUNIC LETTER W
    (29, 33): 'w',  # LATIN LETTER SMALL CAPITAL W
    (30, 128): 'W',  # LATIN CAPITAL LETTER W WITH GRAVE
    (30, 129): 'w',  # LATIN SMALL LETTER W WITH GRAVE
    (30, 130): 'W',  # LATIN CAPITAL LETTER W WITH ACUTE
    (30, 131): 'w',  # LATIN SMALL LETTER W WITH ACUTE
    (30, 132): 'W',  # LATIN CAPITAL LETTER W WITH DIAERESIS
    (30, 133): 'w',  # LATIN SMALL LETTER W WITH DIAERESIS
    (30, 134): 'W',  # LATIN CAPITAL LETTER W WITH DOT ABOVE
    (30, 135): 'w',  # LATIN SMALL LETTER W WITH DOT ABOVE
    (30, 136): 'W',  # LATIN CAPITAL LETTER W WITH DOT BELOW
    (30, 137): 'w',  # LATIN SMALL LETTER W WITH DOT BELOW
    (30, 152): 'w',  # LATIN SMALL LETTER W WITH RING ABOVE
    (227, 80): 'W',  # LATIN CAPITAL LETTER W WITH DOUBLE ACUTE
    (227, 83): 'we',  # LATIN CAPITAL LETTER W WITH LATIN SMALL LETTER E ABOVE
    (227, 87): 'W',  # LATIN CAPITAL LETTER W WITH MACRON
    (231, 80): 'w',  # LATIN SMALL LETTER W WITH DOUBLE ACUTE
    (231, 83): 'we',  # LATIN SMALL LETTER W WITH LATIN SMALL LETTER E ABOVE
    (231, 84): 'wo',  # LATIN SMALL LETTER W WITH LATIN SMALL LETTER O ABOVE
    (231, 87): 'w',  # LATIN SMALL LETTER W WITH MACRON
    (232, 240): 'wa',  # LATIN SMALL LETTER W WITH LATIN SMALL LETTER A ABOVE
    (232, 241): 'wi',  # LATIN SMALL LETTER W WITH LATIN SMALL LETTER I ABOVE
    (232, 242): 'wu',  # LATIN SMALL LETTER W WITH LATIN SMALL LETTER U ABOVE
    (232, 243): 'wv',  # LATIN SMALL LETTER W WITH LATIN SMALL LETTER V ABOVE
    (238, 249): 'w',  # LATIN ENLARGED LETTER SMALL W
    (0, 81): 'Q',  # LATIN CAPITAL LETTER Q
    (0, 113): 'q',  # LATIN SMALL LETTER Q
    (167, 86): 'Q',  # LATIN CAPITAL LETTER Q WITH STROKE THROUGH DESCENDER
    (167, 87): 'q',  # LATIN SMALL LETTER Q WITH STROKE THROUGH DESCENDER
    (167, 88): 'Q',  # LATIN CAPITAL LETTER Q WITH DIAGONAL STROKE
    (167, 89): 'q',  # LATIN SMALL LETTER Q WITH DIAGONAL STROKE
    (226, 130): 'Q',  # LATIN CAPITAL LETTER Q WITH DOT ABOVE
    (226, 136): 'Q',  # LATIN CAPITAL LETTER Q WITH DOT BELOW
    (230, 129): 'q',  # LATIN SMALL LETTER Q WITH MACRON
    (230, 130): 'q',  # LATIN SMALL LETTER Q WITH DOT ABOVE
    (230, 136): 'q',  # LATIN SMALL LETTER Q WITH DOT BELOW
    (230, 139): 'q',  # LATIN SMALL LETTER Q WITH STROKE THROUGH DESCENDER AND TILDE
    (232, 179): 'qr',  # LATIN SMALL LETTER Q LIGATED WITH R ROTUNDA
    (232, 180): 'q',  # LATIN SMALL LETTER Q WITH CENTRAL SLANTED STROKE
    (232, 191): 'qet',  # LATIN SMALL LETTER Q LIGATED WITH FINAL ET
    (234, 209): 'qv',  # LATIN SMALL LIGATURE Q INSULAR V
    (238, 242): 'q',  # LATIN ENLARGED LETTER SMALL Q
    (239, 12): 'Q',  # LATIN LETTER SMALL CAPITAL Q
    (242, 44): 'Q',  # LATIN CAPITAL LETTER Q WITH STEM
    (0, 75): 'K',  # LATIN CAPITAL LETTER K
    (0, 107): 'k',  # LATIN SMALL LETTER K
    (1, 153): 'k',  # LATIN SMALL LETTER K WITH HOOK
    (29, 11): 'k',  # LATIN LETTER SMALL CAPITAL K
    (30, 48): 'K',  # LATIN CAPITAL LETTER K WITH ACUTE
    (30, 49): 'k',  # LATIN SMALL LETTER K WITH ACUTE
    (30, 50): 'K',  # LATIN CAPITAL LETTER K WITH DOT BELOW
    (30, 51): 'k',  # LATIN SMALL LETTER K WITH DOT BELOW
    (167, 64): 'K',  # LATIN CAPITAL LETTER K WITH STROKE
    (167, 65): 'k',  # LATIN SMALL LETTER K WITH STROKE
    (167, 66): 'K',  # LATIN CAPITAL LETTER K WITH DIAGONAL STROKE
    (167, 67): 'k',  # LATIN SMALL LETTER K WITH DIAGONAL STROKE
    (167, 68): 'K',  # LATIN CAPITAL LETTER K WITH STROKE AND DIAGONAL STROKE
    (167, 69): 'k',  # LATIN SMALL LETTER K WITH STROKE AND DIAGONAL STROKE
    (225, 104): 'K',  # LATIN CAPITAL LETTER K WITH DOT ABOVE
    (229, 104): 'k',  # LATIN SMALL LETTER K WITH DOT ABOVE
    (231, 195): 'k',  # LATIN SMALL LETTER K WITH MEDIUM-HIGH OVERLINE (ACROSS ASCENDER)
    (231, 200): 'ks',  # LATIN SMALL LIGATURE K AND LONG S WITH STROKE
    (232, 197): 'kr',  # LATIN SMALL LETTER K LIGATED WITH ARM OF LATIN SMALL LETTER R
    (235, 174): 'ks',  # LATIN SMALL LIGATURE K AND LONG S
    (235, 219): 'K',  # LATIN LETTER SMALL CAPITAL K WITH DOT ABOVE
    (238, 236): 'k',  # LATIN ENLARGED LETTER SMALL K
    (241, 149): 'k',  # LATIN SMALL LETTER K WITH CURL
    (242, 8): 'k',  # LATIN LETTER UNCIAL K
    (242, 9): 'k',  # LATIN SMALL LETTER K CLOSED FORM
    (242, 33): 'k',  # LATIN SMALL LETTER K SEMI-CLOSED FORM
    (0, 79): 'O',  # LATIN CAPITAL LETTER O
    (0, 111): 'o',  # LATIN SMALL LETTER O
    (0, 186): 'O',  # MASCULINE ORDINAL INDICATOR
    (0, 210): 'O',  # LATIN CAPITAL LETTER O WITH GRAVE
    (0, 211): 'O',  # LATIN CAPITAL LETTER O WITH ACUTE
    (0, 212): 'O',  # LATIN CAPITAL LETTER O WITH CIRCUMFLEX
    (0, 213): 'O',  # LATIN CAPITAL LETTER O WITH TILDE
    (0, 214): 'O',  # LATIN CAPITAL LETTER O WITH DIAERESIS
    (0, 216): 'O',  # LATIN CAPITAL LETTER O WITH STROKE
    (0, 242): 'o',  # LATIN SMALL LETTER O WITH GRAVE
    (0, 243): 'o',  # LATIN SMALL LETTER O WITH ACUTE
    (0, 244): 'o',  # LATIN SMALL LETTER O WITH CIRCUMFLEX
    (0, 245): 'o',  # LATIN SMALL LETTER O WITH TILDE
    (0, 246): 'o',  # LATIN SMALL LETTER O WITH DIAERESIS
    (0, 248): 'o',  # LATIN SMALL LETTER O WITH STROKE
    (1, 76): 'O',  # LATIN CAPITAL LETTER O WITH MACRON
    (1, 77): 'o',  # LATIN SMALL LETTER O WITH MACRON
    (1, 78): 'O',  # LATIN CAPITAL LETTER O WITH BREVE
    (1, 79): 'o',  # LATIN SMALL LETTER O WITH BREVE
    (1, 80): 'O',  # LATIN CAPITAL LETTER O WITH DOUBLE ACUTE
    (1, 81): 'o',  # LATIN SMALL LETTER O WITH DOUBLE ACUTE
    (1, 82): 'OE',  # LATIN CAPITAL LIGATURE OE
    (1, 83): 'oe',  # LATIN SMALL LIGATURE OE
    (1, 209): 'O',  # LATIN CAPITAL LETTER O WITH CARON
    (1, 210): 'o',  # LATIN SMALL LETTER O WITH CARON
    (1, 234): 'O',  # LATIN CAPITAL LETTER O WITH OGONEK
    (1, 235): 'o',  # LATIN SMALL LETTER O WITH OGONEK
    (1, 236): 'O',  # LATIN CAPITAL LETTER O WITH OGONEK AND MACRON
    (1, 237): 'o',  # LATIN SMALL LETTER O WITH OGONEK AND MACRON
    (1, 254): 'O',  # LATIN CAPITAL LETTER O WITH STROKE AND ACUTE
    (1, 255): 'o',  # LATIN SMALL LETTER O WITH STROKE AND ACUTE
    (2, 42): 'O',  # LATIN CAPITAL LETTER O WITH DIAERESIS AND MACRON
    (2, 43): 'o',  # LATIN SMALL LETTER O WITH DIAERESIS AND MACRON
    (2, 46): 'O',  # LATIN CAPITAL LETTER O WITH DOT ABOVE
    (2, 47): 'o',  # LATIN SMALL LETTER O WITH DOT ABOVE
    (2, 84): 'o',  # LATIN SMALL LETTER OPEN O
    (2, 118): 'oE',  # LATIN LETTER SMALL CAPITAL OE
    (29, 15): 'o',  # LATIN LETTER SMALL CAPITAL O
    (30, 82): 'O',  # LATIN CAPITAL LETTER O WITH MACRON AND ACUTE
    (30, 83): 'o',  # LATIN SMALL LETTER O WITH MACRON AND ACUTE
    (30, 204): 'O',  # LATIN CAPITAL LETTER O WITH DOT BELOW
    (30, 205): 'o',  # LATIN SMALL LETTER O WITH DOT BELOW
    (30, 206): 'O',  # LATIN CAPITAL LETTER O WITH HOOK ABOVE
    (30, 207): 'o',  # LATIN SMALL LETTER O WITH HOOK ABOVE
    (167, 76): 'oE',  # LATIN SMALL LETTER OE WITH LOOP
    (167, 77): 'Oe',  # LATIN CAPITAL LETTER OE WITH LOOP
    (167, 78): 'OO',  # LATIN CAPITAL LETTER OO
    (167, 79): 'oo',  # LATIN SMALL LETTER OO
    (226, 8): 'O',  # LATIN CAPITAL LETTER O WITH OGONEK AND DOT BELOW
    (226, 12): 'O',  # LATIN CAPITAL LETTER O WITH OGONEK AND ACUTE
    (226, 27): 'O',  # LATIN CAPITAL LETTER O WITH MACRON AND BREVE
    (226, 45): 'O',  # LATIN CAPITAL LETTER O WITH DIAERESIS AND CIRCUMFLEX
    (226, 68): 'OE',  # LATIN CAPITAL LETTER O WITH LATIN SMALL LETTER E ABOVE
    (226, 70): 'OU',  # LATIN CAPITAL LETTER O WITH LATIN SMALL LETTER U ABOVE
    (226, 79): 'O',  # LATIN CAPITAL LETTER O WITH OGONEK AND CURL
    (226, 82): 'O',  # LATIN CAPITAL LETTER O WITH STROKE AND MACRON
    (226, 83): 'O',  # LATIN CAPITAL LETTER O WITH STROKE AND MACRON AND BREVE
    (226, 85): 'O',  # LATIN CAPITAL LETTER O WITH STROKE AND OGONEK
    (226, 87): 'O',  # LATIN CAPITAL LETTER O WITH STROKE AND OGONEK AND ACUTE
    (226, 89): 'OE',  # LATIN CAPITAL LIGATURE OE WITH ACUTE
    (226, 93): 'OE',  # LATIN CAPITAL LIGATURE OE WITH MACRON
    (226, 96): 'OE',  # LATIN CAPITAL LIGATURE OE WITH MACRON AND BREVE
    (226, 98): 'OE',  # LATIN CAPITAL LIGATURE OE WITH OGONEK
    (227, 211): 'O',  # LATIN CAPITAL LETTER O WITH CURL
    (227, 212): 'O',  # LATIN CAPITAL LETTER O WITH STROKE AND CURL
    (230, 8): 'o',  # LATIN SMALL LETTER O WITH OGONEK AND DOT BELOW
    (230, 12): 'o',  # LATIN SMALL LETTER O WITH OGONEK AND ACUTE
    (230, 14): 'o',  # LATIN SMALL LETTER O WITH OGONEK AND CIRCUMFLEX
    (230, 27): 'o',  # LATIN SMALL LETTER O WITH MACRON AND BREVE
    (230, 44): 'o',  # LATIN SMALL LETTER O WITH DIAERESIS AND ACUTE
    (230, 45): 'o',  # LATIN SMALL LETTER O WITH DIAERESIS AND CIRCUMFLEX
    (230, 55): 'o',  # LATIN SMALL LETTER O WITH RING ABOVE
    (230, 67): 'oa',  # LATIN SMALL LETTER O WITH LATIN SMALL LETTER A ABOVE
    (230, 68): 'oe',  # LATIN SMALL LETTER O WITH LATIN SMALL LETTER E ABOVE
    (230, 69): 'oi',  # LATIN SMALL LETTER O WITH LATIN SMALL LETTER I ABOVE
    (230, 70): 'ou',  # LATIN SMALL LETTER O WITH LATIN SMALL LETTER U ABOVE
    (230, 71): 'ov',  # LATIN SMALL LETTER O WITH LATIN SMALL LETTER V ABOVE
    (230, 79): 'o',  # LATIN SMALL LETTER O WITH OGONEK AND CURL
    (230, 82): 'o',  # LATIN SMALL LETTER O WITH STROKE AND MACRON
    (230, 83): 'o',  # LATIN SMALL LETTER O WITH STROKE AND MACRON AND BREVE
    (230, 85): 'o',  # LATIN SMALL LETTER O WITH STROKE AND OGONEK
    (230, 87): 'o',  # LATIN SMALL LETTER O WITH STROKE AND OGONEK AND ACUTE
    (230, 89): 'oe',  # LATIN SMALL LIGATURE OE WITH ACUTE
    (230, 93): 'oe',  # LATIN SMALL LIGATURE OE WITH MACRON
    (230, 96): 'oe',  # LATIN SMALL LIGATURE OE WITH MACRON AND BREVE
    (230, 98): 'oe',  # LATIN SMALL LIGATURE OE WITH OGONEK
    (231, 204): 'o',  # LATIN SMALL LETTER OPEN O WITH MACRON
    (231, 211): 'o',  # LATIN SMALL LETTER O WITH CURL
    (231, 212): 'o',  # LATIN SMALL LETTER O WITH STROKE AND CURL
    (232, 215): 'o',  # LATIN SMALL LETTER O WITH DIAGONAL DIAERESIS
    (232, 222): 'or',  # LATIN SMALL LIGATURE O R ROTUNDA
    (232, 233): 'oo',  # LATIN SMALL LETTER O WITH LATIN SMALL LETTER O ABOVE
    (235, 183): 'O',  # LATIN CAPITAL LETTER O WITH CURL AND ACUTE
    (235, 184): 'o',  # LATIN SMALL LETTER O WITH CURL AND ACUTE
    (235, 196): 'O',  # LATIN CAPITAL LETTER O WITH OGONEK AND DOUBLE ACUTE
    (235, 197): 'o',  # LATIN SMALL LETTER O WITH OGONEK AND DOUBLE ACUTE
    (235, 198): 'O',  # LATIN CAPITAL LETTER O WITH STROKE AND DOUBLE ACUTE
    (235, 199): 'o',  # LATIN SMALL LETTER O WITH STROKE AND DOUBLE ACUTE
    (235, 200): 'OE',  # LATIN CAPITAL LIGATURE OE WITH DOUBLE ACUTE
    (235, 201): 'oe',  # LATIN SMALL LIGATURE OE WITH DOUBLE ACUTE
    (235, 205): 'O',  # LATIN CAPITAL LETTER O WITH STROKE AND DOT ABOVE
    (235, 206): 'o',  # LATIN SMALL LETTER O WITH STROKE AND DOT ABOVE
    (235, 222): 'O',  # LATIN CAPITAL LETTER O WITH OGONEK AND DOT ABOVE
    (235, 223): 'o',  # LATIN SMALL LETTER O WITH OGONEK AND DOT ABOVE
    (235, 224): 'O',  # LATIN CAPITAL LETTER O WITH STROKE AND DOT BELOW
    (235, 225): 'o',  # LATIN SMALL LETTER O WITH STROKE AND DOT BELOW
    (235, 228): 'OO',  # LATIN CAPITAL LIGATURE OO WITH DIAERESIS
    (235, 229): 'oo',  # LATIN SMALL LIGATURE OO WITH DIAERESIS
    (235, 236): 'O',  # LATIN CAPITAL LETTER O WITH STROKE AND MACRON AND ACUTE
    (235, 237): 'o',  # LATIN SMALL LETTER O WITH STROKE AND MACRON AND ACUTE
    (235, 238): 'O',  # LATIN CAPITAL LETTER O WITH STROKE AND BREVE
    (235, 239): 'o',  # LATIN SMALL LETTER O WITH STROKE AND BREVE
    (235, 248): 'O',  # LATIN CAPITAL LETTER O WITH DOT ABOVE AND ACUTE
    (235, 249): 'o',  # LATIN SMALL LETTER O WITH DOT ABOVE AND ACUTE
    (235, 250): 'O',  # LATIN CAPITAL LETTER O WITH OGONEK AND DOT ABOVE AND ACUTE
    (235, 251): 'o',  # LATIN SMALL LETTER O WITH OGONEK AND DOT ABOVE AND ACUTE
    (235, 252): 'O',  # LATIN CAPITAL LETTER O WITH STROKE AND DOT ABOVE AND ACUTE
    (235, 253): 'o',  # LATIN SMALL LETTER O WITH STROKE AND DOT ABOVE AND ACUTE
    (238, 240): 'o',  # LATIN ENLARGED LETTER SMALL O
    (239, 173): 'oc',  # LATIN SMALL LIGATURE OC
    (239, 221): 'oe',  # LATIN ENLARGED LETTER SMALL LIGATURE OE
    (239, 232): 'OO',  # LATIN CAPITAL LIGATURE OO WITH ACUTE
    (239, 233): 'oo',  # LATIN SMALL LIGATURE OO WITH ACUTE
    (239, 236): 'OO',  # LATIN CAPITAL LIGATURE OO WITH DOUBLE ACUTE
    (239, 237): 'oo',  # LATIN SMALL LIGATURE OO WITH DOUBLE ACUTE
    (239, 252): 'OO',  # LATIN CAPITAL LIGATURE OO WITH DOT BELOW
    (239, 253): 'oo',  # LATIN SMALL LIGATURE OO WITH DOT BELOW
    (0, 33): '',  # EXCLAMATION MARK
    (0, 34): '',  # QUOTATION MARK
    (0, 39): '',  # APOSTROPHE
    (0, 40): '',  # LEFT PARENTHESIS
    (0, 41): '',  # RIGHT PARENTHESIS
    (0, 44): '',  # COMMA
    (0, 45): '',  # HYPHEN-MINUS
    (0, 47): '',  # SOLIDUS
    (0, 58): '',  # COLON
    (0, 60): '',  # LESS-THAN SIGN
    (0, 62): '',  # GREATER-THAN SIGN
    (0, 63): '',  # QUESTION MARK
    (0, 91): '',  # LEFT SQUARE BRACKET
    (0, 92): '',  # REVERSE SOLIDUS
    (0, 93): '',  # RIGHT SQUARE BRACKET
    (0, 95): '',  # LOW LINE
    (0, 123): '',  # LEFT CURLY BRACKET
    (0, 124): '',  # VERTICAL LINE
    (0, 125): '',  # RIGHT CURLY BRACKET
    (0, 161): '',  # INVERTED EXCLAMATION MARK
    (0, 166): '',  # BROKEN BAR
    (0, 171): '',  # LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
    (0, 183): '',  # MIDDLE DOT
    (0, 187): '',  # RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
    (0, 191): '',  # INVERTED QUESTION MARK
    (16, 251): '',  # GEORGIAN PARAGRAPH SEPARATOR
    (32, 16): '',  # HYPHEN
    (32, 17): '',  # NON-BREAKING HYPHEN
    (32, 18): '',  # FIGURE DASH
    (32, 19): '',  # EN DASH
    (32, 20): '',  # EM DASH
    (32, 21): '',  # HORIZONTAL BAR
    (32, 22): '',  # DOUBLE VERTICAL LINE
    (32, 24): '',  # LEFT SINGLE QUOTATION MARK
    (32, 25): '',  # RIGHT SINGLE QUOTATION MARK
    (32, 26): '',  # SINGLE LOW-9 QUOTATION MARK
    (32, 27): '',  # SINGLE HIGH-REVERSED-9 QUOTATION MARK
    (32, 28): '',  # LEFT DOUBLE QUOTATION MARK
    (32, 29): '',  # RIGHT DOUBLE QUOTATION MARK
    (32, 30): '',  # DOUBLE LOW-9 QUOTATION MARK
    (32, 31): '',  # DOUBLE HIGH-REVERSED-9 QUOTATION MARK
    (32, 36): '',  # ONE DOT LEADER
    (32, 37): '',  # TWO DOT LEADER
    (32, 38): '',  # HORIZONTAL ELLIPSIS
    (32, 39): '',  # HYPHENATION POINT
    (32, 50): '',  # PRIME
    (32, 51): '',  # DOUBLE PRIME
    (32, 57): '',  # SINGLE LEFT-POINTING ANGLE QUOTATION MARK
    (32, 58): '',  # SINGLE RIGHT-POINTING ANGLE QUOTATION MARK
    (32, 68): '',  # FRACTION SLASH
    (32, 69): '',  # LEFT SQUARE BRACKET WITH QUILL
    (32, 70): '',  # RIGHT SQUARE BRACKET WITH QUILL
    (32, 86): '',  # THREE DOT PUNCTUATION
    (32, 88): '',  # FOUR DOT PUNCTUATION
    (34, 52): '',  # THEREFORE
    (34, 53): '',  # BECAUSE
    (34, 55): '',  # PROPORTION
    (34, 215): '',  # GREATER-THAN WITH DOT
    (39, 230): '',  # LEFT WHITE SQUARE BRACKET
    (39, 231): '',  # RIGHT WHITE SQUARE BRACKET
    (39, 232): '',  # LEFT ANGLE BRACKET
    (39, 233): '',  # RIGHT ANGLE BRACKET
    (42, 253): '',  # PUNCTUATION MARK DOUBLE SOLIDUS
    (46, 0): '',  # RIGHT ANGLE SUBSTITUTION MARKER
    (46, 12): '',  # LEFT UPPER SLANTED STROKE
    (46, 13): '',  # RIGHT UPPER SLANTED STROKE
    (46, 23): '',  # DOUBLE OBLIQUE HYPHEN
    (46, 28): '',  # RIGHT LOWER SLANTED STROKE
    (46, 29): '',  # LEFT LOWER SLANTED STROKE
    (46, 32): '',  # RIGHT VERTICAL BAR WITH QUILL
    (46, 33): '',  # LEFT VERTICAL BAR WITH QUILL
    (46, 34): '',  # TOP LEFT HALF BRACKET
    (46, 35): '',  # TOP RIGHT HALF BRACKET
    (46, 36): '',  # BOTTOM LEFT HALF BRACKET
    (46, 37): '',  # BOTTOM RIGHT HALF BRACKET
    (46, 38): '',  # LEFT SIDEWAYS U BRACKET
    (46, 39): '',  # RIGHT SIDEWAYS U BRACKET
    (46, 40): '',  # LEFT DOUBLE PARENTHESIS
    (46, 41): '',  # RIGHT DOUBLE PARENTHESIS
    (46, 42): '',  # TWO DOTS OVER ONE DOT PUNCTUATION
    (46, 43): '',  # ONE DOT OVER TWO DOTS PUNCTUATION
    (46, 44): '',  # FOUR DOTS PUNCTUATION
    (46, 45): '',  # FIVE DOT MARK
    (46, 46): '',  # REVERSED QUESTION MARK
    (46, 64): '',  # DOUBLE HYPHEN
    (241, 96): '!',  # PUNCTUS INTERROGATIVUS
    (241, 97): ';',  # PUNCTUS ELEVATUS
    (241, 218): '_',  # MIDDLE RING
    (241, 219): '',  # PALM BRANCH
    (241, 224): ',',  # MEDIEVAL COMMA
    (241, 225): '_',  # PARAGRAPHUS
    (241, 226): ',',  # COMMA POSITURA
    (241, 227): ',',  # HIGH COMMA POSITURA (SIMPLEX DUCTUS)
    (241, 228): '.',  # PUNCTUS WITH COMMA POSITURA
    (241, 229): ';',  # COLON WITH MIDDLE COMMA POSITURA
    (241, 230): ',',  # THREE DOTS WITH COMMA POSITURA
    (241, 231): '!',  # PUNCTUS EXCLAMATIVUS
    (241, 232): '!',  # PUNCTUS INTERROGATIVUS HORIZONTAL TILDE
    (241, 234): ';',  # PUNCTUS VERSUS
    (241, 236): '_',  # SIGNE DE RENVOI
    (241, 240): ';',  # PUNCTUS ELEVATUS DIAGONAL STROKE
    (241, 241): '!',  # PUNCTUS INTERROGATIVUS LEMNISKATE FORM
    (241, 242): ',',  # TWO DOTS OVER COMMA POSITURA
    (241, 244): ',',  # VIRGULA SUSPENSIVA
    (241, 245): '.',  # PUNCTUS FLEXUS
    (241, 247): ',',  # SHORT VIRGULA
    (241, 248): '/',  # DISTINCTIO
    (241, 249): '_',  # WAVY LINE
    (241, 250): ';',  # PUNCTUS ELEVATUS WITH HIGH BACK
    (241, 251): ';',  # PUNCTUS ELEVATUS WITH ONSET
}
MUFI[(32, 25)] = "'"
MUFI[(0, 176)] = "*"


def mufidecode(string, join=True, specifics=None):
    """Transliterate Unicode text into plain 7-bit ASCII.

    Example usage:
    >>> from unidecode import unidecode
    >>> string = " soffroient Torm̃z⁊"
    >>> assert unidecode(string) == " soffroient Tormz7"  # Lostfirst character, et is converted to seven.
    >>> assert mufidecode(string) == "et soffroient Tormzet"
    >>> assert mufidecode("ꝮꝯꝮꝯ") == "usususus"
    >>> assert mufidecode(string, join=False) == ('et', ' ', 's', 'o', 'f', 'f', 'r', 'o', 'i', 'e', 'n', 't', ' ', 'T', 'o', 'r', 'm', 'z', 'et')

    """
    retval = []
    if specifics:
        MUFI.update(specifics)

    for char in string:
        codepoint = ord(char)

        if codepoint < 0x80:  # Basic ASCII
            retval.append(str(char))
            continue

        section = codepoint >> 8  # Chop off the last two hex digits
        position = codepoint % 256  # Last two hex digits

        if (section, position) in MUFI:
            retval.append(MUFI[(section, position)])
            continue

        if codepoint > 0xeffff:
            continue  # Characters in Private Use Area and above are ignored

        if 0xd800 <= codepoint <= 0xdfff:
            warnings.warn("Surrogate character %r will be ignored. "
                          "You might be using a narrow Python build." % (char,),
                          RuntimeWarning, 2)

        try:
            table = Cache[section]
        except KeyError:
            try:
                mod = __import__('unidecode.x%03x' % (section), globals(), locals(), ['data'])
            except ImportError:
                Cache[section] = None
                continue  # No match: ignore this character and carry on.

            Cache[section] = table = mod.data

        if table and len(table) > position:
            retval.append(table[position])
            continue

    if join:
        return ''.join(retval)
    return tuple([ret for ret in retval if ret])
